# This file was automatically generated by SWIG (http://www.swig.org).
# Version 3.0.12
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info >= (2, 7, 0):
    def swig_import_helper():
        import importlib
        pkg = __name__.rpartition('.')[0]
        mname = '.'.join((pkg, '_EUSignCP')).lstrip('.')
        try:
            return importlib.import_module(mname)
        except ImportError:
            return importlib.import_module('_EUSignCP')
    _EUSignCP = swig_import_helper()
    del swig_import_helper
elif _swig_python_version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_EUSignCP', [dirname(__file__)])
        except ImportError:
            import _EUSignCP
            return _EUSignCP
        try:
            _mod = imp.load_module('_EUSignCP', fp, pathname, description)
        finally:
            if fp is not None:
                fp.close()
        return _mod
    _EUSignCP = swig_import_helper()
    del swig_import_helper
else:
    import _EUSignCP
del _swig_python_version_info

try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr(self, class_type, name):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    raise AttributeError("'%s' object has no attribute '%s'" % (class_type.__name__, name))


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except __builtin__.Exception:
    class _object:
        pass
    _newclass = 0

NULL = _EUSignCP.NULL
FALSE = _EUSignCP.FALSE
TRUE = _EUSignCP.TRUE
class SYSTEMTIME(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, SYSTEMTIME, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, SYSTEMTIME, name)
    __repr__ = _swig_repr
    __swig_setmethods__["wYear"] = _EUSignCP.SYSTEMTIME_wYear_set
    __swig_getmethods__["wYear"] = _EUSignCP.SYSTEMTIME_wYear_get
    if _newclass:
        wYear = _swig_property(_EUSignCP.SYSTEMTIME_wYear_get, _EUSignCP.SYSTEMTIME_wYear_set)
    __swig_setmethods__["wMonth"] = _EUSignCP.SYSTEMTIME_wMonth_set
    __swig_getmethods__["wMonth"] = _EUSignCP.SYSTEMTIME_wMonth_get
    if _newclass:
        wMonth = _swig_property(_EUSignCP.SYSTEMTIME_wMonth_get, _EUSignCP.SYSTEMTIME_wMonth_set)
    __swig_setmethods__["wDayOfWeek"] = _EUSignCP.SYSTEMTIME_wDayOfWeek_set
    __swig_getmethods__["wDayOfWeek"] = _EUSignCP.SYSTEMTIME_wDayOfWeek_get
    if _newclass:
        wDayOfWeek = _swig_property(_EUSignCP.SYSTEMTIME_wDayOfWeek_get, _EUSignCP.SYSTEMTIME_wDayOfWeek_set)
    __swig_setmethods__["wDay"] = _EUSignCP.SYSTEMTIME_wDay_set
    __swig_getmethods__["wDay"] = _EUSignCP.SYSTEMTIME_wDay_get
    if _newclass:
        wDay = _swig_property(_EUSignCP.SYSTEMTIME_wDay_get, _EUSignCP.SYSTEMTIME_wDay_set)
    __swig_setmethods__["wHour"] = _EUSignCP.SYSTEMTIME_wHour_set
    __swig_getmethods__["wHour"] = _EUSignCP.SYSTEMTIME_wHour_get
    if _newclass:
        wHour = _swig_property(_EUSignCP.SYSTEMTIME_wHour_get, _EUSignCP.SYSTEMTIME_wHour_set)
    __swig_setmethods__["wMinute"] = _EUSignCP.SYSTEMTIME_wMinute_set
    __swig_getmethods__["wMinute"] = _EUSignCP.SYSTEMTIME_wMinute_get
    if _newclass:
        wMinute = _swig_property(_EUSignCP.SYSTEMTIME_wMinute_get, _EUSignCP.SYSTEMTIME_wMinute_set)
    __swig_setmethods__["wSecond"] = _EUSignCP.SYSTEMTIME_wSecond_set
    __swig_getmethods__["wSecond"] = _EUSignCP.SYSTEMTIME_wSecond_get
    if _newclass:
        wSecond = _swig_property(_EUSignCP.SYSTEMTIME_wSecond_get, _EUSignCP.SYSTEMTIME_wSecond_set)
    __swig_setmethods__["wMilliseconds"] = _EUSignCP.SYSTEMTIME_wMilliseconds_set
    __swig_getmethods__["wMilliseconds"] = _EUSignCP.SYSTEMTIME_wMilliseconds_get
    if _newclass:
        wMilliseconds = _swig_property(_EUSignCP.SYSTEMTIME_wMilliseconds_get, _EUSignCP.SYSTEMTIME_wMilliseconds_set)

    def __init__(self):
        this = _EUSignCP.new_SYSTEMTIME()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _EUSignCP.delete_SYSTEMTIME
    __del__ = lambda self: None
SYSTEMTIME_swigregister = _EUSignCP.SYSTEMTIME_swigregister
SYSTEMTIME_swigregister(SYSTEMTIME)

class EU_CERT_OWNER_INFO(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, EU_CERT_OWNER_INFO, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, EU_CERT_OWNER_INFO, name)
    __repr__ = _swig_repr
    __swig_setmethods__["bFilled"] = _EUSignCP.EU_CERT_OWNER_INFO_bFilled_set
    __swig_getmethods__["bFilled"] = _EUSignCP.EU_CERT_OWNER_INFO_bFilled_get
    if _newclass:
        bFilled = _swig_property(_EUSignCP.EU_CERT_OWNER_INFO_bFilled_get, _EUSignCP.EU_CERT_OWNER_INFO_bFilled_set)
    __swig_setmethods__["pszIssuer"] = _EUSignCP.EU_CERT_OWNER_INFO_pszIssuer_set
    __swig_getmethods__["pszIssuer"] = _EUSignCP.EU_CERT_OWNER_INFO_pszIssuer_get
    if _newclass:
        pszIssuer = _swig_property(_EUSignCP.EU_CERT_OWNER_INFO_pszIssuer_get, _EUSignCP.EU_CERT_OWNER_INFO_pszIssuer_set)
    __swig_setmethods__["pszIssuerCN"] = _EUSignCP.EU_CERT_OWNER_INFO_pszIssuerCN_set
    __swig_getmethods__["pszIssuerCN"] = _EUSignCP.EU_CERT_OWNER_INFO_pszIssuerCN_get
    if _newclass:
        pszIssuerCN = _swig_property(_EUSignCP.EU_CERT_OWNER_INFO_pszIssuerCN_get, _EUSignCP.EU_CERT_OWNER_INFO_pszIssuerCN_set)
    __swig_setmethods__["pszSerial"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSerial_set
    __swig_getmethods__["pszSerial"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSerial_get
    if _newclass:
        pszSerial = _swig_property(_EUSignCP.EU_CERT_OWNER_INFO_pszSerial_get, _EUSignCP.EU_CERT_OWNER_INFO_pszSerial_set)
    __swig_setmethods__["pszSubject"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubject_set
    __swig_getmethods__["pszSubject"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubject_get
    if _newclass:
        pszSubject = _swig_property(_EUSignCP.EU_CERT_OWNER_INFO_pszSubject_get, _EUSignCP.EU_CERT_OWNER_INFO_pszSubject_set)
    __swig_setmethods__["pszSubjCN"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjCN_set
    __swig_getmethods__["pszSubjCN"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjCN_get
    if _newclass:
        pszSubjCN = _swig_property(_EUSignCP.EU_CERT_OWNER_INFO_pszSubjCN_get, _EUSignCP.EU_CERT_OWNER_INFO_pszSubjCN_set)
    __swig_setmethods__["pszSubjOrg"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjOrg_set
    __swig_getmethods__["pszSubjOrg"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjOrg_get
    if _newclass:
        pszSubjOrg = _swig_property(_EUSignCP.EU_CERT_OWNER_INFO_pszSubjOrg_get, _EUSignCP.EU_CERT_OWNER_INFO_pszSubjOrg_set)
    __swig_setmethods__["pszSubjOrgUnit"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjOrgUnit_set
    __swig_getmethods__["pszSubjOrgUnit"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjOrgUnit_get
    if _newclass:
        pszSubjOrgUnit = _swig_property(_EUSignCP.EU_CERT_OWNER_INFO_pszSubjOrgUnit_get, _EUSignCP.EU_CERT_OWNER_INFO_pszSubjOrgUnit_set)
    __swig_setmethods__["pszSubjTitle"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjTitle_set
    __swig_getmethods__["pszSubjTitle"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjTitle_get
    if _newclass:
        pszSubjTitle = _swig_property(_EUSignCP.EU_CERT_OWNER_INFO_pszSubjTitle_get, _EUSignCP.EU_CERT_OWNER_INFO_pszSubjTitle_set)
    __swig_setmethods__["pszSubjState"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjState_set
    __swig_getmethods__["pszSubjState"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjState_get
    if _newclass:
        pszSubjState = _swig_property(_EUSignCP.EU_CERT_OWNER_INFO_pszSubjState_get, _EUSignCP.EU_CERT_OWNER_INFO_pszSubjState_set)
    __swig_setmethods__["pszSubjLocality"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjLocality_set
    __swig_getmethods__["pszSubjLocality"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjLocality_get
    if _newclass:
        pszSubjLocality = _swig_property(_EUSignCP.EU_CERT_OWNER_INFO_pszSubjLocality_get, _EUSignCP.EU_CERT_OWNER_INFO_pszSubjLocality_set)
    __swig_setmethods__["pszSubjFullName"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjFullName_set
    __swig_getmethods__["pszSubjFullName"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjFullName_get
    if _newclass:
        pszSubjFullName = _swig_property(_EUSignCP.EU_CERT_OWNER_INFO_pszSubjFullName_get, _EUSignCP.EU_CERT_OWNER_INFO_pszSubjFullName_set)
    __swig_setmethods__["pszSubjAddress"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjAddress_set
    __swig_getmethods__["pszSubjAddress"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjAddress_get
    if _newclass:
        pszSubjAddress = _swig_property(_EUSignCP.EU_CERT_OWNER_INFO_pszSubjAddress_get, _EUSignCP.EU_CERT_OWNER_INFO_pszSubjAddress_set)
    __swig_setmethods__["pszSubjPhone"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjPhone_set
    __swig_getmethods__["pszSubjPhone"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjPhone_get
    if _newclass:
        pszSubjPhone = _swig_property(_EUSignCP.EU_CERT_OWNER_INFO_pszSubjPhone_get, _EUSignCP.EU_CERT_OWNER_INFO_pszSubjPhone_set)
    __swig_setmethods__["pszSubjEMail"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjEMail_set
    __swig_getmethods__["pszSubjEMail"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjEMail_get
    if _newclass:
        pszSubjEMail = _swig_property(_EUSignCP.EU_CERT_OWNER_INFO_pszSubjEMail_get, _EUSignCP.EU_CERT_OWNER_INFO_pszSubjEMail_set)
    __swig_setmethods__["pszSubjDNS"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjDNS_set
    __swig_getmethods__["pszSubjDNS"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjDNS_get
    if _newclass:
        pszSubjDNS = _swig_property(_EUSignCP.EU_CERT_OWNER_INFO_pszSubjDNS_get, _EUSignCP.EU_CERT_OWNER_INFO_pszSubjDNS_set)
    __swig_setmethods__["pszSubjEDRPOUCode"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjEDRPOUCode_set
    __swig_getmethods__["pszSubjEDRPOUCode"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjEDRPOUCode_get
    if _newclass:
        pszSubjEDRPOUCode = _swig_property(_EUSignCP.EU_CERT_OWNER_INFO_pszSubjEDRPOUCode_get, _EUSignCP.EU_CERT_OWNER_INFO_pszSubjEDRPOUCode_set)
    __swig_setmethods__["pszSubjDRFOCode"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjDRFOCode_set
    __swig_getmethods__["pszSubjDRFOCode"] = _EUSignCP.EU_CERT_OWNER_INFO_pszSubjDRFOCode_get
    if _newclass:
        pszSubjDRFOCode = _swig_property(_EUSignCP.EU_CERT_OWNER_INFO_pszSubjDRFOCode_get, _EUSignCP.EU_CERT_OWNER_INFO_pszSubjDRFOCode_set)

    def __init__(self):
        this = _EUSignCP.new_EU_CERT_OWNER_INFO()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _EUSignCP.delete_EU_CERT_OWNER_INFO
    __del__ = lambda self: None
EU_CERT_OWNER_INFO_swigregister = _EUSignCP.EU_CERT_OWNER_INFO_swigregister
EU_CERT_OWNER_INFO_swigregister(EU_CERT_OWNER_INFO)

class EU_SIGN_INFO(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, EU_SIGN_INFO, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, EU_SIGN_INFO, name)
    __repr__ = _swig_repr
    __swig_setmethods__["bFilled"] = _EUSignCP.EU_SIGN_INFO_bFilled_set
    __swig_getmethods__["bFilled"] = _EUSignCP.EU_SIGN_INFO_bFilled_get
    if _newclass:
        bFilled = _swig_property(_EUSignCP.EU_SIGN_INFO_bFilled_get, _EUSignCP.EU_SIGN_INFO_bFilled_set)
    __swig_setmethods__["pszIssuer"] = _EUSignCP.EU_SIGN_INFO_pszIssuer_set
    __swig_getmethods__["pszIssuer"] = _EUSignCP.EU_SIGN_INFO_pszIssuer_get
    if _newclass:
        pszIssuer = _swig_property(_EUSignCP.EU_SIGN_INFO_pszIssuer_get, _EUSignCP.EU_SIGN_INFO_pszIssuer_set)
    __swig_setmethods__["pszIssuerCN"] = _EUSignCP.EU_SIGN_INFO_pszIssuerCN_set
    __swig_getmethods__["pszIssuerCN"] = _EUSignCP.EU_SIGN_INFO_pszIssuerCN_get
    if _newclass:
        pszIssuerCN = _swig_property(_EUSignCP.EU_SIGN_INFO_pszIssuerCN_get, _EUSignCP.EU_SIGN_INFO_pszIssuerCN_set)
    __swig_setmethods__["pszSerial"] = _EUSignCP.EU_SIGN_INFO_pszSerial_set
    __swig_getmethods__["pszSerial"] = _EUSignCP.EU_SIGN_INFO_pszSerial_get
    if _newclass:
        pszSerial = _swig_property(_EUSignCP.EU_SIGN_INFO_pszSerial_get, _EUSignCP.EU_SIGN_INFO_pszSerial_set)
    __swig_setmethods__["pszSubject"] = _EUSignCP.EU_SIGN_INFO_pszSubject_set
    __swig_getmethods__["pszSubject"] = _EUSignCP.EU_SIGN_INFO_pszSubject_get
    if _newclass:
        pszSubject = _swig_property(_EUSignCP.EU_SIGN_INFO_pszSubject_get, _EUSignCP.EU_SIGN_INFO_pszSubject_set)
    __swig_setmethods__["pszSubjCN"] = _EUSignCP.EU_SIGN_INFO_pszSubjCN_set
    __swig_getmethods__["pszSubjCN"] = _EUSignCP.EU_SIGN_INFO_pszSubjCN_get
    if _newclass:
        pszSubjCN = _swig_property(_EUSignCP.EU_SIGN_INFO_pszSubjCN_get, _EUSignCP.EU_SIGN_INFO_pszSubjCN_set)
    __swig_setmethods__["pszSubjOrg"] = _EUSignCP.EU_SIGN_INFO_pszSubjOrg_set
    __swig_getmethods__["pszSubjOrg"] = _EUSignCP.EU_SIGN_INFO_pszSubjOrg_get
    if _newclass:
        pszSubjOrg = _swig_property(_EUSignCP.EU_SIGN_INFO_pszSubjOrg_get, _EUSignCP.EU_SIGN_INFO_pszSubjOrg_set)
    __swig_setmethods__["pszSubjOrgUnit"] = _EUSignCP.EU_SIGN_INFO_pszSubjOrgUnit_set
    __swig_getmethods__["pszSubjOrgUnit"] = _EUSignCP.EU_SIGN_INFO_pszSubjOrgUnit_get
    if _newclass:
        pszSubjOrgUnit = _swig_property(_EUSignCP.EU_SIGN_INFO_pszSubjOrgUnit_get, _EUSignCP.EU_SIGN_INFO_pszSubjOrgUnit_set)
    __swig_setmethods__["pszSubjTitle"] = _EUSignCP.EU_SIGN_INFO_pszSubjTitle_set
    __swig_getmethods__["pszSubjTitle"] = _EUSignCP.EU_SIGN_INFO_pszSubjTitle_get
    if _newclass:
        pszSubjTitle = _swig_property(_EUSignCP.EU_SIGN_INFO_pszSubjTitle_get, _EUSignCP.EU_SIGN_INFO_pszSubjTitle_set)
    __swig_setmethods__["pszSubjState"] = _EUSignCP.EU_SIGN_INFO_pszSubjState_set
    __swig_getmethods__["pszSubjState"] = _EUSignCP.EU_SIGN_INFO_pszSubjState_get
    if _newclass:
        pszSubjState = _swig_property(_EUSignCP.EU_SIGN_INFO_pszSubjState_get, _EUSignCP.EU_SIGN_INFO_pszSubjState_set)
    __swig_setmethods__["pszSubjLocality"] = _EUSignCP.EU_SIGN_INFO_pszSubjLocality_set
    __swig_getmethods__["pszSubjLocality"] = _EUSignCP.EU_SIGN_INFO_pszSubjLocality_get
    if _newclass:
        pszSubjLocality = _swig_property(_EUSignCP.EU_SIGN_INFO_pszSubjLocality_get, _EUSignCP.EU_SIGN_INFO_pszSubjLocality_set)
    __swig_setmethods__["pszSubjFullName"] = _EUSignCP.EU_SIGN_INFO_pszSubjFullName_set
    __swig_getmethods__["pszSubjFullName"] = _EUSignCP.EU_SIGN_INFO_pszSubjFullName_get
    if _newclass:
        pszSubjFullName = _swig_property(_EUSignCP.EU_SIGN_INFO_pszSubjFullName_get, _EUSignCP.EU_SIGN_INFO_pszSubjFullName_set)
    __swig_setmethods__["pszSubjAddress"] = _EUSignCP.EU_SIGN_INFO_pszSubjAddress_set
    __swig_getmethods__["pszSubjAddress"] = _EUSignCP.EU_SIGN_INFO_pszSubjAddress_get
    if _newclass:
        pszSubjAddress = _swig_property(_EUSignCP.EU_SIGN_INFO_pszSubjAddress_get, _EUSignCP.EU_SIGN_INFO_pszSubjAddress_set)
    __swig_setmethods__["pszSubjPhone"] = _EUSignCP.EU_SIGN_INFO_pszSubjPhone_set
    __swig_getmethods__["pszSubjPhone"] = _EUSignCP.EU_SIGN_INFO_pszSubjPhone_get
    if _newclass:
        pszSubjPhone = _swig_property(_EUSignCP.EU_SIGN_INFO_pszSubjPhone_get, _EUSignCP.EU_SIGN_INFO_pszSubjPhone_set)
    __swig_setmethods__["pszSubjEMail"] = _EUSignCP.EU_SIGN_INFO_pszSubjEMail_set
    __swig_getmethods__["pszSubjEMail"] = _EUSignCP.EU_SIGN_INFO_pszSubjEMail_get
    if _newclass:
        pszSubjEMail = _swig_property(_EUSignCP.EU_SIGN_INFO_pszSubjEMail_get, _EUSignCP.EU_SIGN_INFO_pszSubjEMail_set)
    __swig_setmethods__["pszSubjDNS"] = _EUSignCP.EU_SIGN_INFO_pszSubjDNS_set
    __swig_getmethods__["pszSubjDNS"] = _EUSignCP.EU_SIGN_INFO_pszSubjDNS_get
    if _newclass:
        pszSubjDNS = _swig_property(_EUSignCP.EU_SIGN_INFO_pszSubjDNS_get, _EUSignCP.EU_SIGN_INFO_pszSubjDNS_set)
    __swig_setmethods__["pszSubjEDRPOUCode"] = _EUSignCP.EU_SIGN_INFO_pszSubjEDRPOUCode_set
    __swig_getmethods__["pszSubjEDRPOUCode"] = _EUSignCP.EU_SIGN_INFO_pszSubjEDRPOUCode_get
    if _newclass:
        pszSubjEDRPOUCode = _swig_property(_EUSignCP.EU_SIGN_INFO_pszSubjEDRPOUCode_get, _EUSignCP.EU_SIGN_INFO_pszSubjEDRPOUCode_set)
    __swig_setmethods__["pszSubjDRFOCode"] = _EUSignCP.EU_SIGN_INFO_pszSubjDRFOCode_set
    __swig_getmethods__["pszSubjDRFOCode"] = _EUSignCP.EU_SIGN_INFO_pszSubjDRFOCode_get
    if _newclass:
        pszSubjDRFOCode = _swig_property(_EUSignCP.EU_SIGN_INFO_pszSubjDRFOCode_get, _EUSignCP.EU_SIGN_INFO_pszSubjDRFOCode_set)
    __swig_setmethods__["bTimeAvail"] = _EUSignCP.EU_SIGN_INFO_bTimeAvail_set
    __swig_getmethods__["bTimeAvail"] = _EUSignCP.EU_SIGN_INFO_bTimeAvail_get
    if _newclass:
        bTimeAvail = _swig_property(_EUSignCP.EU_SIGN_INFO_bTimeAvail_get, _EUSignCP.EU_SIGN_INFO_bTimeAvail_set)
    __swig_setmethods__["bTimeStamp"] = _EUSignCP.EU_SIGN_INFO_bTimeStamp_set
    __swig_getmethods__["bTimeStamp"] = _EUSignCP.EU_SIGN_INFO_bTimeStamp_get
    if _newclass:
        bTimeStamp = _swig_property(_EUSignCP.EU_SIGN_INFO_bTimeStamp_get, _EUSignCP.EU_SIGN_INFO_bTimeStamp_set)
    __swig_setmethods__["Time"] = _EUSignCP.EU_SIGN_INFO_Time_set
    __swig_getmethods__["Time"] = _EUSignCP.EU_SIGN_INFO_Time_get
    if _newclass:
        Time = _swig_property(_EUSignCP.EU_SIGN_INFO_Time_get, _EUSignCP.EU_SIGN_INFO_Time_set)

    def __init__(self):
        this = _EUSignCP.new_EU_SIGN_INFO()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _EUSignCP.delete_EU_SIGN_INFO
    __del__ = lambda self: None
EU_SIGN_INFO_swigregister = _EUSignCP.EU_SIGN_INFO_swigregister
EU_SIGN_INFO_swigregister(EU_SIGN_INFO)

EU_PASS_MAX_LENGTH = _EUSignCP.EU_PASS_MAX_LENGTH
class EU_KEY_MEDIA(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, EU_KEY_MEDIA, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, EU_KEY_MEDIA, name)
    __repr__ = _swig_repr
    __swig_setmethods__["dwTypeIndex"] = _EUSignCP.EU_KEY_MEDIA_dwTypeIndex_set
    __swig_getmethods__["dwTypeIndex"] = _EUSignCP.EU_KEY_MEDIA_dwTypeIndex_get
    if _newclass:
        dwTypeIndex = _swig_property(_EUSignCP.EU_KEY_MEDIA_dwTypeIndex_get, _EUSignCP.EU_KEY_MEDIA_dwTypeIndex_set)
    __swig_setmethods__["dwDevIndex"] = _EUSignCP.EU_KEY_MEDIA_dwDevIndex_set
    __swig_getmethods__["dwDevIndex"] = _EUSignCP.EU_KEY_MEDIA_dwDevIndex_get
    if _newclass:
        dwDevIndex = _swig_property(_EUSignCP.EU_KEY_MEDIA_dwDevIndex_get, _EUSignCP.EU_KEY_MEDIA_dwDevIndex_set)
    __swig_setmethods__["szPassword"] = _EUSignCP.EU_KEY_MEDIA_szPassword_set
    __swig_getmethods__["szPassword"] = _EUSignCP.EU_KEY_MEDIA_szPassword_get
    if _newclass:
        szPassword = _swig_property(_EUSignCP.EU_KEY_MEDIA_szPassword_get, _EUSignCP.EU_KEY_MEDIA_szPassword_set)

    def __init__(self):
        this = _EUSignCP.new_EU_KEY_MEDIA()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _EUSignCP.delete_EU_KEY_MEDIA
    __del__ = lambda self: None
EU_KEY_MEDIA_swigregister = _EUSignCP.EU_KEY_MEDIA_swigregister
EU_KEY_MEDIA_swigregister(EU_KEY_MEDIA)

EU_ERROR_MAX_LENGTH = _EUSignCP.EU_ERROR_MAX_LENGTH
EU_SIGNER_INFO_MAX_LENGTH = _EUSignCP.EU_SIGNER_INFO_MAX_LENGTH
EU_KEY_MEDIA_NAME_MAX_LENGTH = _EUSignCP.EU_KEY_MEDIA_NAME_MAX_LENGTH
EU_KEY_MEDIA_MAX_TYPES = _EUSignCP.EU_KEY_MEDIA_MAX_TYPES
EU_KEY_MEDIA_MAX_DEVICES = _EUSignCP.EU_KEY_MEDIA_MAX_DEVICES
EU_KEY_MEDIA_SOURCE_TYPE_OPERATOR = _EUSignCP.EU_KEY_MEDIA_SOURCE_TYPE_OPERATOR
EU_KEY_MEDIA_SOURCE_TYPE_FIXED = _EUSignCP.EU_KEY_MEDIA_SOURCE_TYPE_FIXED
EU_PATH_MAX_LENGTH = _EUSignCP.EU_PATH_MAX_LENGTH
EU_ISSUER_MAX_LENGTH = _EUSignCP.EU_ISSUER_MAX_LENGTH
EU_SERIAL_MAX_LENGTH = _EUSignCP.EU_SERIAL_MAX_LENGTH
EU_COMMON_NAME_MAX_LENGTH = _EUSignCP.EU_COMMON_NAME_MAX_LENGTH
EU_COUNTRY_MAX_LENGTH = _EUSignCP.EU_COUNTRY_MAX_LENGTH
EU_LOCALITY_MAX_LENGTH = _EUSignCP.EU_LOCALITY_MAX_LENGTH
EU_STATE_MAX_LENGTH = _EUSignCP.EU_STATE_MAX_LENGTH
EU_ORGANIZATION_MAX_LENGTH = _EUSignCP.EU_ORGANIZATION_MAX_LENGTH
EU_ORG_UNIT_MAX_LENGTH = _EUSignCP.EU_ORG_UNIT_MAX_LENGTH
EU_TITLE_MAX_LENGTH = _EUSignCP.EU_TITLE_MAX_LENGTH
EU_STREET_MAX_LENGTH = _EUSignCP.EU_STREET_MAX_LENGTH
EU_PHONE_MAX_LENGTH = _EUSignCP.EU_PHONE_MAX_LENGTH
EU_SURNAME_MAX_LENGTH = _EUSignCP.EU_SURNAME_MAX_LENGTH
EU_GIVENNAME_MAX_LENGTH = _EUSignCP.EU_GIVENNAME_MAX_LENGTH
EU_EMAIL_MAX_LENGTH = _EUSignCP.EU_EMAIL_MAX_LENGTH
EU_ADDRESS_MAX_LENGTH = _EUSignCP.EU_ADDRESS_MAX_LENGTH
EU_EDRPOU_MAX_LENGTH = _EUSignCP.EU_EDRPOU_MAX_LENGTH
EU_DRFO_MAX_LENGTH = _EUSignCP.EU_DRFO_MAX_LENGTH
EU_NBU_MAX_LENGTH = _EUSignCP.EU_NBU_MAX_LENGTH
EU_SPFM_MAX_LENGTH = _EUSignCP.EU_SPFM_MAX_LENGTH
EU_O_CODE_MAX_LENGTH = _EUSignCP.EU_O_CODE_MAX_LENGTH
EU_OU_CODE_MAX_LENGTH = _EUSignCP.EU_OU_CODE_MAX_LENGTH
EU_USER_CODE_MAX_LENGTH = _EUSignCP.EU_USER_CODE_MAX_LENGTH
EU_UPN_MAX_LENGTH = _EUSignCP.EU_UPN_MAX_LENGTH
EU_UNZR_MAX_LENGTH = _EUSignCP.EU_UNZR_MAX_LENGTH
EU_PORT_MAX_LENGTH = _EUSignCP.EU_PORT_MAX_LENGTH
EU_USER_NAME_MAX_LENGTH = _EUSignCP.EU_USER_NAME_MAX_LENGTH
EU_POLICIES_MAX_LENGTH = _EUSignCP.EU_POLICIES_MAX_LENGTH
EU_SUBJECT_TYPE_UNDIFFERENCED = _EUSignCP.EU_SUBJECT_TYPE_UNDIFFERENCED
EU_SUBJECT_TYPE_CA = _EUSignCP.EU_SUBJECT_TYPE_CA
EU_SUBJECT_TYPE_CA_SERVER = _EUSignCP.EU_SUBJECT_TYPE_CA_SERVER
EU_SUBJECT_TYPE_RA_ADMINISTRATOR = _EUSignCP.EU_SUBJECT_TYPE_RA_ADMINISTRATOR
EU_SUBJECT_TYPE_END_USER = _EUSignCP.EU_SUBJECT_TYPE_END_USER
EU_SUBJECT_CA_SERVER_SUB_TYPE_UNDIFFERENCED = _EUSignCP.EU_SUBJECT_CA_SERVER_SUB_TYPE_UNDIFFERENCED
EU_SUBJECT_CA_SERVER_SUB_TYPE_CMP = _EUSignCP.EU_SUBJECT_CA_SERVER_SUB_TYPE_CMP
EU_SUBJECT_CA_SERVER_SUB_TYPE_TSP = _EUSignCP.EU_SUBJECT_CA_SERVER_SUB_TYPE_TSP
EU_SUBJECT_CA_SERVER_SUB_TYPE_OCSP = _EUSignCP.EU_SUBJECT_CA_SERVER_SUB_TYPE_OCSP
EU_CERT_INFO_VERSION = _EUSignCP.EU_CERT_INFO_VERSION
EU_CERT_INFO_EX_VERSION_2 = _EUSignCP.EU_CERT_INFO_EX_VERSION_2
EU_CERT_INFO_EX_VERSION_3 = _EUSignCP.EU_CERT_INFO_EX_VERSION_3
EU_CERT_INFO_EX_VERSION_4 = _EUSignCP.EU_CERT_INFO_EX_VERSION_4
EU_CERT_INFO_EX_VERSION_5 = _EUSignCP.EU_CERT_INFO_EX_VERSION_5
EU_CERT_INFO_EX_VERSION = _EUSignCP.EU_CERT_INFO_EX_VERSION
EU_CRL_DETAILED_INFO_VERSION = _EUSignCP.EU_CRL_DETAILED_INFO_VERSION
EU_CR_INFO_VERSION_1 = _EUSignCP.EU_CR_INFO_VERSION_1
EU_CR_INFO_VERSION_2 = _EUSignCP.EU_CR_INFO_VERSION_2
EU_CR_INFO_VERSION = _EUSignCP.EU_CR_INFO_VERSION
EU_USER_INFO_VERSION_1 = _EUSignCP.EU_USER_INFO_VERSION_1
EU_USER_INFO_VERSION_2 = _EUSignCP.EU_USER_INFO_VERSION_2
EU_USER_INFO_VERSION = _EUSignCP.EU_USER_INFO_VERSION
EU_SCC_STATISTIC_VERSION = _EUSignCP.EU_SCC_STATISTIC_VERSION
EU_TIME_INFO_VERSION_1 = _EUSignCP.EU_TIME_INFO_VERSION_1
EU_TIME_INFO_VERSION = _EUSignCP.EU_TIME_INFO_VERSION
EU_KEY_MEDIA_DEVICE_INFO_VERSION = _EUSignCP.EU_KEY_MEDIA_DEVICE_INFO_VERSION
EU_CERT_KEY_TYPE_UNKNOWN = _EUSignCP.EU_CERT_KEY_TYPE_UNKNOWN
EU_CERT_KEY_TYPE_DSTU4145 = _EUSignCP.EU_CERT_KEY_TYPE_DSTU4145
EU_CERT_KEY_TYPE_RSA = _EUSignCP.EU_CERT_KEY_TYPE_RSA
EU_CERT_KEY_TYPE_ECDSA = _EUSignCP.EU_CERT_KEY_TYPE_ECDSA
EU_KEY_USAGE_UNKNOWN = _EUSignCP.EU_KEY_USAGE_UNKNOWN
EU_KEY_USAGE_DIGITAL_SIGNATURE = _EUSignCP.EU_KEY_USAGE_DIGITAL_SIGNATURE
EU_KEY_USAGE_KEY_AGREEMENT = _EUSignCP.EU_KEY_USAGE_KEY_AGREEMENT
EU_KEYS_TYPE_NONE = _EUSignCP.EU_KEYS_TYPE_NONE
EU_KEYS_TYPE_DSTU_AND_ECDH_WITH_GOSTS = _EUSignCP.EU_KEYS_TYPE_DSTU_AND_ECDH_WITH_GOSTS
EU_KEYS_TYPE_RSA_WITH_SHA = _EUSignCP.EU_KEYS_TYPE_RSA_WITH_SHA
EU_KEYS_LENGTH_DS_UA_191 = _EUSignCP.EU_KEYS_LENGTH_DS_UA_191
EU_KEYS_LENGTH_DS_UA_257 = _EUSignCP.EU_KEYS_LENGTH_DS_UA_257
EU_KEYS_LENGTH_DS_UA_307 = _EUSignCP.EU_KEYS_LENGTH_DS_UA_307
EU_KEYS_LENGTH_DS_UA_FILE = _EUSignCP.EU_KEYS_LENGTH_DS_UA_FILE
EU_KEYS_LENGTH_DS_UA_CERT = _EUSignCP.EU_KEYS_LENGTH_DS_UA_CERT
EU_KEYS_LENGTH_KEP_UA_257 = _EUSignCP.EU_KEYS_LENGTH_KEP_UA_257
EU_KEYS_LENGTH_KEP_UA_431 = _EUSignCP.EU_KEYS_LENGTH_KEP_UA_431
EU_KEYS_LENGTH_KEP_UA_571 = _EUSignCP.EU_KEYS_LENGTH_KEP_UA_571
EU_KEYS_LENGTH_KEP_UA_FILE = _EUSignCP.EU_KEYS_LENGTH_KEP_UA_FILE
EU_KEYS_LENGTH_KEP_UA_CERT = _EUSignCP.EU_KEYS_LENGTH_KEP_UA_CERT
EU_KEYS_LENGTH_DS_RSA_1024 = _EUSignCP.EU_KEYS_LENGTH_DS_RSA_1024
EU_KEYS_LENGTH_DS_RSA_2048 = _EUSignCP.EU_KEYS_LENGTH_DS_RSA_2048
EU_KEYS_LENGTH_DS_RSA_3072 = _EUSignCP.EU_KEYS_LENGTH_DS_RSA_3072
EU_KEYS_LENGTH_DS_RSA_4096 = _EUSignCP.EU_KEYS_LENGTH_DS_RSA_4096
EU_KEYS_LENGTH_DS_FILE = _EUSignCP.EU_KEYS_LENGTH_DS_FILE
EU_KEYS_LENGTH_DS_RSA_FILE = _EUSignCP.EU_KEYS_LENGTH_DS_RSA_FILE
EU_KEYS_LENGTH_DS_RSA_CERT = _EUSignCP.EU_KEYS_LENGTH_DS_RSA_CERT
EU_DEFAULT_LANG = _EUSignCP.EU_DEFAULT_LANG
EU_UA_LANG = _EUSignCP.EU_UA_LANG
EU_RU_LANG = _EUSignCP.EU_RU_LANG
EU_EN_LANG = _EUSignCP.EU_EN_LANG
EU_RESOLVE_OIDS_PARAMETER = _EUSignCP.EU_RESOLVE_OIDS_PARAMETER
EU_RESOLVE_OIDS_PARAMETER_LENGTH = _EUSignCP.EU_RESOLVE_OIDS_PARAMETER_LENGTH
EU_SAVE_SETTINGS_PARAMETER = _EUSignCP.EU_SAVE_SETTINGS_PARAMETER
EU_SAVE_SETTINGS_PARAMETER_LENGTH = _EUSignCP.EU_SAVE_SETTINGS_PARAMETER_LENGTH
EU_UI_MODE_PARAMETER = _EUSignCP.EU_UI_MODE_PARAMETER
EU_UI_MODE_LENGTH = _EUSignCP.EU_UI_MODE_LENGTH
EU_SHOW_ERRORS_PARAMETER = _EUSignCP.EU_SHOW_ERRORS_PARAMETER
EU_SHOW_ERRORS_LENGTH = _EUSignCP.EU_SHOW_ERRORS_LENGTH
EU_MAKE_PKEY_PFX_CONTAINER_PARAMETER = _EUSignCP.EU_MAKE_PKEY_PFX_CONTAINER_PARAMETER
EU_MAKE_PKEY_PFX_CONTAINER_LENGTH = _EUSignCP.EU_MAKE_PKEY_PFX_CONTAINER_LENGTH
EU_NO_CSP_SELF_TESTS_PARAMETER = _EUSignCP.EU_NO_CSP_SELF_TESTS_PARAMETER
EU_NO_CSP_SELF_TESTS_LENGTH = _EUSignCP.EU_NO_CSP_SELF_TESTS_LENGTH
EU_SIGN_INCLUDE_CONTENT_TIME_STAMP_PARAMETER = _EUSignCP.EU_SIGN_INCLUDE_CONTENT_TIME_STAMP_PARAMETER
EU_SIGN_INCLUDE_CONTENT_TIME_STAMP_LENGTH = _EUSignCP.EU_SIGN_INCLUDE_CONTENT_TIME_STAMP_LENGTH
EU_SIGN_TYPE_PARAMETER = _EUSignCP.EU_SIGN_TYPE_PARAMETER
EU_SIGN_TYPE_LENGTH = _EUSignCP.EU_SIGN_TYPE_LENGTH
EU_SIGN_INCLUDE_CA_CERTIFICATES_PARAMETER = _EUSignCP.EU_SIGN_INCLUDE_CA_CERTIFICATES_PARAMETER
EU_SIGN_INCLUDE_CA_CERTIFICATES_LENGTH = _EUSignCP.EU_SIGN_INCLUDE_CA_CERTIFICATES_LENGTH
EU_FS_CALCULATE_FINGERPRINT = _EUSignCP.EU_FS_CALCULATE_FINGERPRINT
EU_FS_CALCULATE_FINGERPRINT_LENGTH = _EUSignCP.EU_FS_CALCULATE_FINGERPRINT_LENGTH
EU_FP_RESET = _EUSignCP.EU_FP_RESET
EU_FP_RESET_LENGTH = _EUSignCP.EU_FP_RESET_LENGTH
EU_RECIPIENT_APPEND_TYPE_BY_ISSUER_SERIAL = _EUSignCP.EU_RECIPIENT_APPEND_TYPE_BY_ISSUER_SERIAL
EU_RECIPIENT_APPEND_TYPE_BY_KEY_ID = _EUSignCP.EU_RECIPIENT_APPEND_TYPE_BY_KEY_ID
EU_STORAGE_VALUE_MAX_LENGTH = _EUSignCP.EU_STORAGE_VALUE_MAX_LENGTH
EU_SETTINGS_ID_NONE = _EUSignCP.EU_SETTINGS_ID_NONE
EU_SETTINGS_ID_ALL = _EUSignCP.EU_SETTINGS_ID_ALL
EU_SETTINGS_ID_FSTORE = _EUSignCP.EU_SETTINGS_ID_FSTORE
EU_SETTINGS_ID_PROXY = _EUSignCP.EU_SETTINGS_ID_PROXY
EU_SETTINGS_ID_TSP = _EUSignCP.EU_SETTINGS_ID_TSP
EU_SETTINGS_ID_OCSP = _EUSignCP.EU_SETTINGS_ID_OCSP
EU_SETTINGS_ID_LDAP = _EUSignCP.EU_SETTINGS_ID_LDAP
EU_SETTINGS_ID_MANDATORY = _EUSignCP.EU_SETTINGS_ID_MANDATORY
EU_SETTINGS_ID_MODE = _EUSignCP.EU_SETTINGS_ID_MODE
EU_SETTINGS_ID_CMP = _EUSignCP.EU_SETTINGS_ID_CMP
EU_SETTINGS_ID_KM = _EUSignCP.EU_SETTINGS_ID_KM
EU_SETTINGS_ID_OCSP_ACCESS_INFO_MODE = _EUSignCP.EU_SETTINGS_ID_OCSP_ACCESS_INFO_MODE
EU_SETTINGS_ID_OCSP_ACCESS_INFO = _EUSignCP.EU_SETTINGS_ID_OCSP_ACCESS_INFO
EU_OCSP_SERVER_STATE_UNKNOWN = _EUSignCP.EU_OCSP_SERVER_STATE_UNKNOWN
EU_OCSP_SERVER_STATE_AVAILABLE = _EUSignCP.EU_OCSP_SERVER_STATE_AVAILABLE
EU_OCSP_SERVER_STATE_UNAVAILABLE = _EUSignCP.EU_OCSP_SERVER_STATE_UNAVAILABLE
EU_SIGN_TYPE_UNKNOWN = _EUSignCP.EU_SIGN_TYPE_UNKNOWN
EU_SIGN_TYPE_CADES_BES = _EUSignCP.EU_SIGN_TYPE_CADES_BES
EU_SIGN_TYPE_CADES_T = _EUSignCP.EU_SIGN_TYPE_CADES_T
EU_SIGN_TYPE_CADES_C = _EUSignCP.EU_SIGN_TYPE_CADES_C
EU_SIGN_TYPE_CADES_X_LONG = _EUSignCP.EU_SIGN_TYPE_CADES_X_LONG
EU_CHECK_PRIVATE_KEY_CONTEXT_PARAMETER = _EUSignCP.EU_CHECK_PRIVATE_KEY_CONTEXT_PARAMETER
EU_CHECK_PRIVATE_KEY_CONTEXT_PARAMETER_LENGTH = _EUSignCP.EU_CHECK_PRIVATE_KEY_CONTEXT_PARAMETER_LENGTH
EU_RESOLVE_OIDS_CONTEXT_PARAMETER = _EUSignCP.EU_RESOLVE_OIDS_CONTEXT_PARAMETER
EU_RESOLVE_OIDS_CONTEXT_PARAMETER_LENGTH = _EUSignCP.EU_RESOLVE_OIDS_CONTEXT_PARAMETER_LENGTH
EU_EXPORATABLE_CONTEXT_CONTEXT_PARAMETER = _EUSignCP.EU_EXPORATABLE_CONTEXT_CONTEXT_PARAMETER
EU_EXPORATABLE_CONTEXT_CONTEXT_PARAMETER_LENGTH = _EUSignCP.EU_EXPORATABLE_CONTEXT_CONTEXT_PARAMETER_LENGTH
EU_RECIPIENT_INFO_TYPE_ISSUER_SERIAL = _EUSignCP.EU_RECIPIENT_INFO_TYPE_ISSUER_SERIAL
EU_RECIPIENT_INFO_TYPE_KEY_ID = _EUSignCP.EU_RECIPIENT_INFO_TYPE_KEY_ID
EU_CTX_HASH_ALGO_UNKNOWN = _EUSignCP.EU_CTX_HASH_ALGO_UNKNOWN
EU_CTX_HASH_ALGO_GOST34311 = _EUSignCP.EU_CTX_HASH_ALGO_GOST34311
EU_CTX_HASH_ALGO_SHA160 = _EUSignCP.EU_CTX_HASH_ALGO_SHA160
EU_CTX_HASH_ALGO_SHA224 = _EUSignCP.EU_CTX_HASH_ALGO_SHA224
EU_CTX_HASH_ALGO_SHA256 = _EUSignCP.EU_CTX_HASH_ALGO_SHA256
EU_CTX_SIGN_UNKNOWN = _EUSignCP.EU_CTX_SIGN_UNKNOWN
EU_CTX_SIGN_DSTU4145_WITH_GOST34311 = _EUSignCP.EU_CTX_SIGN_DSTU4145_WITH_GOST34311
EU_CTX_SIGN_RSA_WITH_SHA = _EUSignCP.EU_CTX_SIGN_RSA_WITH_SHA
EU_CTX_SIGN_ECDSA_WITH_SHA = _EUSignCP.EU_CTX_SIGN_ECDSA_WITH_SHA
EU_REG_KEY_ROOT_PATH_DEFAULT = _EUSignCP.EU_REG_KEY_ROOT_PATH_DEFAULT
EU_REG_KEY_ROOT_PATH_HKLM = _EUSignCP.EU_REG_KEY_ROOT_PATH_HKLM
EU_REG_KEY_ROOT_PATH_HKCU = _EUSignCP.EU_REG_KEY_ROOT_PATH_HKCU
EU_REG_KEY_ROOT_PATH_CURRENT = _EUSignCP.EU_REG_KEY_ROOT_PATH_CURRENT
EU_CONTENT_ENC_ALGO_TDES_CBC = _EUSignCP.EU_CONTENT_ENC_ALGO_TDES_CBC
EU_CONTENT_ENC_ALGO_AES_128_CBC = _EUSignCP.EU_CONTENT_ENC_ALGO_AES_128_CBC
EU_CONTENT_ENC_ALGO_AES_192_CBC = _EUSignCP.EU_CONTENT_ENC_ALGO_AES_192_CBC
EU_CONTENT_ENC_ALGO_AES_256_CBC = _EUSignCP.EU_CONTENT_ENC_ALGO_AES_256_CBC
EU_DEV_CTX_MIN_PUBLIC_DATA_ID = _EUSignCP.EU_DEV_CTX_MIN_PUBLIC_DATA_ID
EU_DEV_CTX_MAX_PUBLIC_DATA_ID = _EUSignCP.EU_DEV_CTX_MAX_PUBLIC_DATA_ID
EU_DEV_CTX_MIN_CONST_PUBLIC_DATA_ID = _EUSignCP.EU_DEV_CTX_MIN_CONST_PUBLIC_DATA_ID
EU_DEV_CTX_MAX_CONST_PUBLIC_DATA_ID = _EUSignCP.EU_DEV_CTX_MAX_CONST_PUBLIC_DATA_ID
EU_DEV_CTX_MIN_CONST_PRIVATE_DATA_ID = _EUSignCP.EU_DEV_CTX_MIN_CONST_PRIVATE_DATA_ID
EU_DEV_CTX_MAX_CONST_PRIVATE_DATA_ID = _EUSignCP.EU_DEV_CTX_MAX_CONST_PRIVATE_DATA_ID
EU_DEV_CTX_MIN_PRIVATE_DATA_ID = _EUSignCP.EU_DEV_CTX_MIN_PRIVATE_DATA_ID
EU_DEV_CTX_MAX_PRIVATE_DATA_ID = _EUSignCP.EU_DEV_CTX_MAX_PRIVATE_DATA_ID
EU_DEV_CTX_DATA_ID_SERIAL_NUMBER = _EUSignCP.EU_DEV_CTX_DATA_ID_SERIAL_NUMBER
EU_DEV_CTX_DATA_ID_SYSTEM_KEY_VERSION = _EUSignCP.EU_DEV_CTX_DATA_ID_SYSTEM_KEY_VERSION
EU_DEV_CTX_DATA_ID_UPDATE_COUNTER = _EUSignCP.EU_DEV_CTX_DATA_ID_UPDATE_COUNTER
EU_DEV_CTX_SYSTEM_KEY_TYPE_INDEX = _EUSignCP.EU_DEV_CTX_SYSTEM_KEY_TYPE_INDEX
EU_DEV_CTX_SYSTEM_KEY_VERSION_INDEX = _EUSignCP.EU_DEV_CTX_SYSTEM_KEY_VERSION_INDEX
EU_HEADER_CA_TYPE = _EUSignCP.EU_HEADER_CA_TYPE
EU_HEADER_PART_TYPE_SIGNED = _EUSignCP.EU_HEADER_PART_TYPE_SIGNED
EU_HEADER_PART_TYPE_ENCRYPTED = _EUSignCP.EU_HEADER_PART_TYPE_ENCRYPTED
EU_HEADER_PART_TYPE_STAMPED = _EUSignCP.EU_HEADER_PART_TYPE_STAMPED
EU_HEADER_PART_TYPE_CERTCRYPT = _EUSignCP.EU_HEADER_PART_TYPE_CERTCRYPT
EU_HEADER_MAX_CA_TYPE_SIZE = _EUSignCP.EU_HEADER_MAX_CA_TYPE_SIZE
EU_CCS_TYPE_REVOKE = _EUSignCP.EU_CCS_TYPE_REVOKE
EU_CCS_TYPE_HOLD = _EUSignCP.EU_CCS_TYPE_HOLD
EU_REVOCATION_REASON_UNKNOWN = _EUSignCP.EU_REVOCATION_REASON_UNKNOWN
EU_REVOCATION_REASON_KEY_COMPROMISE = _EUSignCP.EU_REVOCATION_REASON_KEY_COMPROMISE
EU_REVOCATION_REASON_NEW_ISSUED = _EUSignCP.EU_REVOCATION_REASON_NEW_ISSUED
EU_DEV_CTX_IDCARD_PASSWORD_VERSION_1 = _EUSignCP.EU_DEV_CTX_IDCARD_PASSWORD_VERSION_1
EU_DEV_CTX_IDCARD_PASSWORD_VERSION_2 = _EUSignCP.EU_DEV_CTX_IDCARD_PASSWORD_VERSION_2
EU_DEV_CTX_IDCARD_DG32_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG32_DATA_ID
EU_DEV_CTX_IDCARD_DG33_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG33_DATA_ID
EU_DEV_CTX_IDCARD_DG34_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG34_DATA_ID
EU_DEV_CTX_IDCARD_DG35_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG35_DATA_ID
EU_DEV_CTX_IDCARD_DG36_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG36_DATA_ID
EU_DEV_CTX_IDCARD_DG37_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG37_DATA_ID
EU_DEV_CTX_IDCARD_DG38_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG38_DATA_ID
EU_NAMED_PRIVATE_KEY_LABEL_MAX_LENGTH = _EUSignCP.EU_NAMED_PRIVATE_KEY_LABEL_MAX_LENGTH
EU_DEV_CTX_IDCARD_COM_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_COM_DATA_ID
EU_DEV_CTX_IDCARD_DG1_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG1_DATA_ID
EU_DEV_CTX_IDCARD_DG2_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG2_DATA_ID
EU_DEV_CTX_IDCARD_DG3_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG3_DATA_ID
EU_DEV_CTX_IDCARD_DG4_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG4_DATA_ID
EU_DEV_CTX_IDCARD_DG5_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG5_DATA_ID
EU_DEV_CTX_IDCARD_DG6_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG6_DATA_ID
EU_DEV_CTX_IDCARD_DG7_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG7_DATA_ID
EU_DEV_CTX_IDCARD_DG8_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG8_DATA_ID
EU_DEV_CTX_IDCARD_DG9_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG9_DATA_ID
EU_DEV_CTX_IDCARD_DG10_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG10_DATA_ID
EU_DEV_CTX_IDCARD_DG11_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG11_DATA_ID
EU_DEV_CTX_IDCARD_DG12_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG12_DATA_ID
EU_DEV_CTX_IDCARD_DG13_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG13_DATA_ID
EU_DEV_CTX_IDCARD_DG14_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG14_DATA_ID
EU_DEV_CTX_IDCARD_DG15_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG15_DATA_ID
EU_DEV_CTX_IDCARD_DG16_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_DG16_DATA_ID
EU_DEV_CTX_IDCARD_SOD_DATA_ID = _EUSignCP.EU_DEV_CTX_IDCARD_SOD_DATA_ID
class EU_CRL_INFO(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, EU_CRL_INFO, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, EU_CRL_INFO, name)
    __repr__ = _swig_repr
    __swig_setmethods__["bFilled"] = _EUSignCP.EU_CRL_INFO_bFilled_set
    __swig_getmethods__["bFilled"] = _EUSignCP.EU_CRL_INFO_bFilled_get
    if _newclass:
        bFilled = _swig_property(_EUSignCP.EU_CRL_INFO_bFilled_get, _EUSignCP.EU_CRL_INFO_bFilled_set)
    __swig_setmethods__["pszIssuer"] = _EUSignCP.EU_CRL_INFO_pszIssuer_set
    __swig_getmethods__["pszIssuer"] = _EUSignCP.EU_CRL_INFO_pszIssuer_get
    if _newclass:
        pszIssuer = _swig_property(_EUSignCP.EU_CRL_INFO_pszIssuer_get, _EUSignCP.EU_CRL_INFO_pszIssuer_set)
    __swig_setmethods__["pszIssuerCN"] = _EUSignCP.EU_CRL_INFO_pszIssuerCN_set
    __swig_getmethods__["pszIssuerCN"] = _EUSignCP.EU_CRL_INFO_pszIssuerCN_get
    if _newclass:
        pszIssuerCN = _swig_property(_EUSignCP.EU_CRL_INFO_pszIssuerCN_get, _EUSignCP.EU_CRL_INFO_pszIssuerCN_set)
    __swig_setmethods__["dwCRLNumber"] = _EUSignCP.EU_CRL_INFO_dwCRLNumber_set
    __swig_getmethods__["dwCRLNumber"] = _EUSignCP.EU_CRL_INFO_dwCRLNumber_get
    if _newclass:
        dwCRLNumber = _swig_property(_EUSignCP.EU_CRL_INFO_dwCRLNumber_get, _EUSignCP.EU_CRL_INFO_dwCRLNumber_set)
    __swig_setmethods__["stThisUpdate"] = _EUSignCP.EU_CRL_INFO_stThisUpdate_set
    __swig_getmethods__["stThisUpdate"] = _EUSignCP.EU_CRL_INFO_stThisUpdate_get
    if _newclass:
        stThisUpdate = _swig_property(_EUSignCP.EU_CRL_INFO_stThisUpdate_get, _EUSignCP.EU_CRL_INFO_stThisUpdate_set)
    __swig_setmethods__["stNextUpdate"] = _EUSignCP.EU_CRL_INFO_stNextUpdate_set
    __swig_getmethods__["stNextUpdate"] = _EUSignCP.EU_CRL_INFO_stNextUpdate_get
    if _newclass:
        stNextUpdate = _swig_property(_EUSignCP.EU_CRL_INFO_stNextUpdate_get, _EUSignCP.EU_CRL_INFO_stNextUpdate_set)

    def __init__(self):
        this = _EUSignCP.new_EU_CRL_INFO()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _EUSignCP.delete_EU_CRL_INFO
    __del__ = lambda self: None
EU_CRL_INFO_swigregister = _EUSignCP.EU_CRL_INFO_swigregister
EU_CRL_INFO_swigregister(EU_CRL_INFO)

class EU_CERT_INFO(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, EU_CERT_INFO, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, EU_CERT_INFO, name)
    __repr__ = _swig_repr
    __swig_setmethods__["bFilled"] = _EUSignCP.EU_CERT_INFO_bFilled_set
    __swig_getmethods__["bFilled"] = _EUSignCP.EU_CERT_INFO_bFilled_get
    if _newclass:
        bFilled = _swig_property(_EUSignCP.EU_CERT_INFO_bFilled_get, _EUSignCP.EU_CERT_INFO_bFilled_set)
    __swig_setmethods__["dwVersion"] = _EUSignCP.EU_CERT_INFO_dwVersion_set
    __swig_getmethods__["dwVersion"] = _EUSignCP.EU_CERT_INFO_dwVersion_get
    if _newclass:
        dwVersion = _swig_property(_EUSignCP.EU_CERT_INFO_dwVersion_get, _EUSignCP.EU_CERT_INFO_dwVersion_set)
    __swig_setmethods__["pszIssuer"] = _EUSignCP.EU_CERT_INFO_pszIssuer_set
    __swig_getmethods__["pszIssuer"] = _EUSignCP.EU_CERT_INFO_pszIssuer_get
    if _newclass:
        pszIssuer = _swig_property(_EUSignCP.EU_CERT_INFO_pszIssuer_get, _EUSignCP.EU_CERT_INFO_pszIssuer_set)
    __swig_setmethods__["pszIssuerCN"] = _EUSignCP.EU_CERT_INFO_pszIssuerCN_set
    __swig_getmethods__["pszIssuerCN"] = _EUSignCP.EU_CERT_INFO_pszIssuerCN_get
    if _newclass:
        pszIssuerCN = _swig_property(_EUSignCP.EU_CERT_INFO_pszIssuerCN_get, _EUSignCP.EU_CERT_INFO_pszIssuerCN_set)
    __swig_setmethods__["pszSerial"] = _EUSignCP.EU_CERT_INFO_pszSerial_set
    __swig_getmethods__["pszSerial"] = _EUSignCP.EU_CERT_INFO_pszSerial_get
    if _newclass:
        pszSerial = _swig_property(_EUSignCP.EU_CERT_INFO_pszSerial_get, _EUSignCP.EU_CERT_INFO_pszSerial_set)
    __swig_setmethods__["pszSubject"] = _EUSignCP.EU_CERT_INFO_pszSubject_set
    __swig_getmethods__["pszSubject"] = _EUSignCP.EU_CERT_INFO_pszSubject_get
    if _newclass:
        pszSubject = _swig_property(_EUSignCP.EU_CERT_INFO_pszSubject_get, _EUSignCP.EU_CERT_INFO_pszSubject_set)
    __swig_setmethods__["pszSubjCN"] = _EUSignCP.EU_CERT_INFO_pszSubjCN_set
    __swig_getmethods__["pszSubjCN"] = _EUSignCP.EU_CERT_INFO_pszSubjCN_get
    if _newclass:
        pszSubjCN = _swig_property(_EUSignCP.EU_CERT_INFO_pszSubjCN_get, _EUSignCP.EU_CERT_INFO_pszSubjCN_set)
    __swig_setmethods__["pszSubjOrg"] = _EUSignCP.EU_CERT_INFO_pszSubjOrg_set
    __swig_getmethods__["pszSubjOrg"] = _EUSignCP.EU_CERT_INFO_pszSubjOrg_get
    if _newclass:
        pszSubjOrg = _swig_property(_EUSignCP.EU_CERT_INFO_pszSubjOrg_get, _EUSignCP.EU_CERT_INFO_pszSubjOrg_set)
    __swig_setmethods__["pszSubjOrgUnit"] = _EUSignCP.EU_CERT_INFO_pszSubjOrgUnit_set
    __swig_getmethods__["pszSubjOrgUnit"] = _EUSignCP.EU_CERT_INFO_pszSubjOrgUnit_get
    if _newclass:
        pszSubjOrgUnit = _swig_property(_EUSignCP.EU_CERT_INFO_pszSubjOrgUnit_get, _EUSignCP.EU_CERT_INFO_pszSubjOrgUnit_set)
    __swig_setmethods__["pszSubjTitle"] = _EUSignCP.EU_CERT_INFO_pszSubjTitle_set
    __swig_getmethods__["pszSubjTitle"] = _EUSignCP.EU_CERT_INFO_pszSubjTitle_get
    if _newclass:
        pszSubjTitle = _swig_property(_EUSignCP.EU_CERT_INFO_pszSubjTitle_get, _EUSignCP.EU_CERT_INFO_pszSubjTitle_set)
    __swig_setmethods__["pszSubjState"] = _EUSignCP.EU_CERT_INFO_pszSubjState_set
    __swig_getmethods__["pszSubjState"] = _EUSignCP.EU_CERT_INFO_pszSubjState_get
    if _newclass:
        pszSubjState = _swig_property(_EUSignCP.EU_CERT_INFO_pszSubjState_get, _EUSignCP.EU_CERT_INFO_pszSubjState_set)
    __swig_setmethods__["pszSubjLocality"] = _EUSignCP.EU_CERT_INFO_pszSubjLocality_set
    __swig_getmethods__["pszSubjLocality"] = _EUSignCP.EU_CERT_INFO_pszSubjLocality_get
    if _newclass:
        pszSubjLocality = _swig_property(_EUSignCP.EU_CERT_INFO_pszSubjLocality_get, _EUSignCP.EU_CERT_INFO_pszSubjLocality_set)
    __swig_setmethods__["pszSubjFullName"] = _EUSignCP.EU_CERT_INFO_pszSubjFullName_set
    __swig_getmethods__["pszSubjFullName"] = _EUSignCP.EU_CERT_INFO_pszSubjFullName_get
    if _newclass:
        pszSubjFullName = _swig_property(_EUSignCP.EU_CERT_INFO_pszSubjFullName_get, _EUSignCP.EU_CERT_INFO_pszSubjFullName_set)
    __swig_setmethods__["pszSubjAddress"] = _EUSignCP.EU_CERT_INFO_pszSubjAddress_set
    __swig_getmethods__["pszSubjAddress"] = _EUSignCP.EU_CERT_INFO_pszSubjAddress_get
    if _newclass:
        pszSubjAddress = _swig_property(_EUSignCP.EU_CERT_INFO_pszSubjAddress_get, _EUSignCP.EU_CERT_INFO_pszSubjAddress_set)
    __swig_setmethods__["pszSubjPhone"] = _EUSignCP.EU_CERT_INFO_pszSubjPhone_set
    __swig_getmethods__["pszSubjPhone"] = _EUSignCP.EU_CERT_INFO_pszSubjPhone_get
    if _newclass:
        pszSubjPhone = _swig_property(_EUSignCP.EU_CERT_INFO_pszSubjPhone_get, _EUSignCP.EU_CERT_INFO_pszSubjPhone_set)
    __swig_setmethods__["pszSubjEMail"] = _EUSignCP.EU_CERT_INFO_pszSubjEMail_set
    __swig_getmethods__["pszSubjEMail"] = _EUSignCP.EU_CERT_INFO_pszSubjEMail_get
    if _newclass:
        pszSubjEMail = _swig_property(_EUSignCP.EU_CERT_INFO_pszSubjEMail_get, _EUSignCP.EU_CERT_INFO_pszSubjEMail_set)
    __swig_setmethods__["pszSubjDNS"] = _EUSignCP.EU_CERT_INFO_pszSubjDNS_set
    __swig_getmethods__["pszSubjDNS"] = _EUSignCP.EU_CERT_INFO_pszSubjDNS_get
    if _newclass:
        pszSubjDNS = _swig_property(_EUSignCP.EU_CERT_INFO_pszSubjDNS_get, _EUSignCP.EU_CERT_INFO_pszSubjDNS_set)
    __swig_setmethods__["pszSubjEDRPOUCode"] = _EUSignCP.EU_CERT_INFO_pszSubjEDRPOUCode_set
    __swig_getmethods__["pszSubjEDRPOUCode"] = _EUSignCP.EU_CERT_INFO_pszSubjEDRPOUCode_get
    if _newclass:
        pszSubjEDRPOUCode = _swig_property(_EUSignCP.EU_CERT_INFO_pszSubjEDRPOUCode_get, _EUSignCP.EU_CERT_INFO_pszSubjEDRPOUCode_set)
    __swig_setmethods__["pszSubjDRFOCode"] = _EUSignCP.EU_CERT_INFO_pszSubjDRFOCode_set
    __swig_getmethods__["pszSubjDRFOCode"] = _EUSignCP.EU_CERT_INFO_pszSubjDRFOCode_get
    if _newclass:
        pszSubjDRFOCode = _swig_property(_EUSignCP.EU_CERT_INFO_pszSubjDRFOCode_get, _EUSignCP.EU_CERT_INFO_pszSubjDRFOCode_set)
    __swig_setmethods__["pszSubjNBUCode"] = _EUSignCP.EU_CERT_INFO_pszSubjNBUCode_set
    __swig_getmethods__["pszSubjNBUCode"] = _EUSignCP.EU_CERT_INFO_pszSubjNBUCode_get
    if _newclass:
        pszSubjNBUCode = _swig_property(_EUSignCP.EU_CERT_INFO_pszSubjNBUCode_get, _EUSignCP.EU_CERT_INFO_pszSubjNBUCode_set)
    __swig_setmethods__["pszSubjSPFMCode"] = _EUSignCP.EU_CERT_INFO_pszSubjSPFMCode_set
    __swig_getmethods__["pszSubjSPFMCode"] = _EUSignCP.EU_CERT_INFO_pszSubjSPFMCode_get
    if _newclass:
        pszSubjSPFMCode = _swig_property(_EUSignCP.EU_CERT_INFO_pszSubjSPFMCode_get, _EUSignCP.EU_CERT_INFO_pszSubjSPFMCode_set)
    __swig_setmethods__["pszSubjOCode"] = _EUSignCP.EU_CERT_INFO_pszSubjOCode_set
    __swig_getmethods__["pszSubjOCode"] = _EUSignCP.EU_CERT_INFO_pszSubjOCode_get
    if _newclass:
        pszSubjOCode = _swig_property(_EUSignCP.EU_CERT_INFO_pszSubjOCode_get, _EUSignCP.EU_CERT_INFO_pszSubjOCode_set)
    __swig_setmethods__["pszSubjOUCode"] = _EUSignCP.EU_CERT_INFO_pszSubjOUCode_set
    __swig_getmethods__["pszSubjOUCode"] = _EUSignCP.EU_CERT_INFO_pszSubjOUCode_get
    if _newclass:
        pszSubjOUCode = _swig_property(_EUSignCP.EU_CERT_INFO_pszSubjOUCode_get, _EUSignCP.EU_CERT_INFO_pszSubjOUCode_set)
    __swig_setmethods__["pszSubjUserCode"] = _EUSignCP.EU_CERT_INFO_pszSubjUserCode_set
    __swig_getmethods__["pszSubjUserCode"] = _EUSignCP.EU_CERT_INFO_pszSubjUserCode_get
    if _newclass:
        pszSubjUserCode = _swig_property(_EUSignCP.EU_CERT_INFO_pszSubjUserCode_get, _EUSignCP.EU_CERT_INFO_pszSubjUserCode_set)
    __swig_setmethods__["stCertBeginTime"] = _EUSignCP.EU_CERT_INFO_stCertBeginTime_set
    __swig_getmethods__["stCertBeginTime"] = _EUSignCP.EU_CERT_INFO_stCertBeginTime_get
    if _newclass:
        stCertBeginTime = _swig_property(_EUSignCP.EU_CERT_INFO_stCertBeginTime_get, _EUSignCP.EU_CERT_INFO_stCertBeginTime_set)
    __swig_setmethods__["stCertEndTime"] = _EUSignCP.EU_CERT_INFO_stCertEndTime_set
    __swig_getmethods__["stCertEndTime"] = _EUSignCP.EU_CERT_INFO_stCertEndTime_get
    if _newclass:
        stCertEndTime = _swig_property(_EUSignCP.EU_CERT_INFO_stCertEndTime_get, _EUSignCP.EU_CERT_INFO_stCertEndTime_set)
    __swig_setmethods__["bPrivKeyTimes"] = _EUSignCP.EU_CERT_INFO_bPrivKeyTimes_set
    __swig_getmethods__["bPrivKeyTimes"] = _EUSignCP.EU_CERT_INFO_bPrivKeyTimes_get
    if _newclass:
        bPrivKeyTimes = _swig_property(_EUSignCP.EU_CERT_INFO_bPrivKeyTimes_get, _EUSignCP.EU_CERT_INFO_bPrivKeyTimes_set)
    __swig_setmethods__["stPrivKeyBeginTime"] = _EUSignCP.EU_CERT_INFO_stPrivKeyBeginTime_set
    __swig_getmethods__["stPrivKeyBeginTime"] = _EUSignCP.EU_CERT_INFO_stPrivKeyBeginTime_get
    if _newclass:
        stPrivKeyBeginTime = _swig_property(_EUSignCP.EU_CERT_INFO_stPrivKeyBeginTime_get, _EUSignCP.EU_CERT_INFO_stPrivKeyBeginTime_set)
    __swig_setmethods__["stPrivKeyEndTime"] = _EUSignCP.EU_CERT_INFO_stPrivKeyEndTime_set
    __swig_getmethods__["stPrivKeyEndTime"] = _EUSignCP.EU_CERT_INFO_stPrivKeyEndTime_get
    if _newclass:
        stPrivKeyEndTime = _swig_property(_EUSignCP.EU_CERT_INFO_stPrivKeyEndTime_get, _EUSignCP.EU_CERT_INFO_stPrivKeyEndTime_set)
    __swig_setmethods__["dwPublicKeyBits"] = _EUSignCP.EU_CERT_INFO_dwPublicKeyBits_set
    __swig_getmethods__["dwPublicKeyBits"] = _EUSignCP.EU_CERT_INFO_dwPublicKeyBits_get
    if _newclass:
        dwPublicKeyBits = _swig_property(_EUSignCP.EU_CERT_INFO_dwPublicKeyBits_get, _EUSignCP.EU_CERT_INFO_dwPublicKeyBits_set)
    __swig_setmethods__["pszPublicKey"] = _EUSignCP.EU_CERT_INFO_pszPublicKey_set
    __swig_getmethods__["pszPublicKey"] = _EUSignCP.EU_CERT_INFO_pszPublicKey_get
    if _newclass:
        pszPublicKey = _swig_property(_EUSignCP.EU_CERT_INFO_pszPublicKey_get, _EUSignCP.EU_CERT_INFO_pszPublicKey_set)
    __swig_setmethods__["pszPublicKeyID"] = _EUSignCP.EU_CERT_INFO_pszPublicKeyID_set
    __swig_getmethods__["pszPublicKeyID"] = _EUSignCP.EU_CERT_INFO_pszPublicKeyID_get
    if _newclass:
        pszPublicKeyID = _swig_property(_EUSignCP.EU_CERT_INFO_pszPublicKeyID_get, _EUSignCP.EU_CERT_INFO_pszPublicKeyID_set)
    __swig_setmethods__["bECDHPublicKey"] = _EUSignCP.EU_CERT_INFO_bECDHPublicKey_set
    __swig_getmethods__["bECDHPublicKey"] = _EUSignCP.EU_CERT_INFO_bECDHPublicKey_get
    if _newclass:
        bECDHPublicKey = _swig_property(_EUSignCP.EU_CERT_INFO_bECDHPublicKey_get, _EUSignCP.EU_CERT_INFO_bECDHPublicKey_set)
    __swig_setmethods__["dwECDHPublicKeyBits"] = _EUSignCP.EU_CERT_INFO_dwECDHPublicKeyBits_set
    __swig_getmethods__["dwECDHPublicKeyBits"] = _EUSignCP.EU_CERT_INFO_dwECDHPublicKeyBits_get
    if _newclass:
        dwECDHPublicKeyBits = _swig_property(_EUSignCP.EU_CERT_INFO_dwECDHPublicKeyBits_get, _EUSignCP.EU_CERT_INFO_dwECDHPublicKeyBits_set)
    __swig_setmethods__["pszECDHPublicKey"] = _EUSignCP.EU_CERT_INFO_pszECDHPublicKey_set
    __swig_getmethods__["pszECDHPublicKey"] = _EUSignCP.EU_CERT_INFO_pszECDHPublicKey_get
    if _newclass:
        pszECDHPublicKey = _swig_property(_EUSignCP.EU_CERT_INFO_pszECDHPublicKey_get, _EUSignCP.EU_CERT_INFO_pszECDHPublicKey_set)
    __swig_setmethods__["pszECDHPublicKeyID"] = _EUSignCP.EU_CERT_INFO_pszECDHPublicKeyID_set
    __swig_getmethods__["pszECDHPublicKeyID"] = _EUSignCP.EU_CERT_INFO_pszECDHPublicKeyID_get
    if _newclass:
        pszECDHPublicKeyID = _swig_property(_EUSignCP.EU_CERT_INFO_pszECDHPublicKeyID_get, _EUSignCP.EU_CERT_INFO_pszECDHPublicKeyID_set)
    __swig_setmethods__["pszIssuerPublicKeyID"] = _EUSignCP.EU_CERT_INFO_pszIssuerPublicKeyID_set
    __swig_getmethods__["pszIssuerPublicKeyID"] = _EUSignCP.EU_CERT_INFO_pszIssuerPublicKeyID_get
    if _newclass:
        pszIssuerPublicKeyID = _swig_property(_EUSignCP.EU_CERT_INFO_pszIssuerPublicKeyID_get, _EUSignCP.EU_CERT_INFO_pszIssuerPublicKeyID_set)
    __swig_setmethods__["pszKeyUsage"] = _EUSignCP.EU_CERT_INFO_pszKeyUsage_set
    __swig_getmethods__["pszKeyUsage"] = _EUSignCP.EU_CERT_INFO_pszKeyUsage_get
    if _newclass:
        pszKeyUsage = _swig_property(_EUSignCP.EU_CERT_INFO_pszKeyUsage_get, _EUSignCP.EU_CERT_INFO_pszKeyUsage_set)
    __swig_setmethods__["pszExtKeyUsages"] = _EUSignCP.EU_CERT_INFO_pszExtKeyUsages_set
    __swig_getmethods__["pszExtKeyUsages"] = _EUSignCP.EU_CERT_INFO_pszExtKeyUsages_get
    if _newclass:
        pszExtKeyUsages = _swig_property(_EUSignCP.EU_CERT_INFO_pszExtKeyUsages_get, _EUSignCP.EU_CERT_INFO_pszExtKeyUsages_set)
    __swig_setmethods__["pszPolicies"] = _EUSignCP.EU_CERT_INFO_pszPolicies_set
    __swig_getmethods__["pszPolicies"] = _EUSignCP.EU_CERT_INFO_pszPolicies_get
    if _newclass:
        pszPolicies = _swig_property(_EUSignCP.EU_CERT_INFO_pszPolicies_get, _EUSignCP.EU_CERT_INFO_pszPolicies_set)
    __swig_setmethods__["pszCRLDistribPoint1"] = _EUSignCP.EU_CERT_INFO_pszCRLDistribPoint1_set
    __swig_getmethods__["pszCRLDistribPoint1"] = _EUSignCP.EU_CERT_INFO_pszCRLDistribPoint1_get
    if _newclass:
        pszCRLDistribPoint1 = _swig_property(_EUSignCP.EU_CERT_INFO_pszCRLDistribPoint1_get, _EUSignCP.EU_CERT_INFO_pszCRLDistribPoint1_set)
    __swig_setmethods__["pszCRLDistribPoint2"] = _EUSignCP.EU_CERT_INFO_pszCRLDistribPoint2_set
    __swig_getmethods__["pszCRLDistribPoint2"] = _EUSignCP.EU_CERT_INFO_pszCRLDistribPoint2_get
    if _newclass:
        pszCRLDistribPoint2 = _swig_property(_EUSignCP.EU_CERT_INFO_pszCRLDistribPoint2_get, _EUSignCP.EU_CERT_INFO_pszCRLDistribPoint2_set)
    __swig_setmethods__["bPowerCert"] = _EUSignCP.EU_CERT_INFO_bPowerCert_set
    __swig_getmethods__["bPowerCert"] = _EUSignCP.EU_CERT_INFO_bPowerCert_get
    if _newclass:
        bPowerCert = _swig_property(_EUSignCP.EU_CERT_INFO_bPowerCert_get, _EUSignCP.EU_CERT_INFO_bPowerCert_set)
    __swig_setmethods__["bSubjType"] = _EUSignCP.EU_CERT_INFO_bSubjType_set
    __swig_getmethods__["bSubjType"] = _EUSignCP.EU_CERT_INFO_bSubjType_get
    if _newclass:
        bSubjType = _swig_property(_EUSignCP.EU_CERT_INFO_bSubjType_get, _EUSignCP.EU_CERT_INFO_bSubjType_set)
    __swig_setmethods__["bSubjCA"] = _EUSignCP.EU_CERT_INFO_bSubjCA_set
    __swig_getmethods__["bSubjCA"] = _EUSignCP.EU_CERT_INFO_bSubjCA_get
    if _newclass:
        bSubjCA = _swig_property(_EUSignCP.EU_CERT_INFO_bSubjCA_get, _EUSignCP.EU_CERT_INFO_bSubjCA_set)

    def __init__(self):
        this = _EUSignCP.new_EU_CERT_INFO()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _EUSignCP.delete_EU_CERT_INFO
    __del__ = lambda self: None
EU_CERT_INFO_swigregister = _EUSignCP.EU_CERT_INFO_swigregister
EU_CERT_INFO_swigregister(EU_CERT_INFO)

class EU_CERT_INFO_EX(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, EU_CERT_INFO_EX, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, EU_CERT_INFO_EX, name)
    __repr__ = _swig_repr
    __swig_setmethods__["bFilled"] = _EUSignCP.EU_CERT_INFO_EX_bFilled_set
    __swig_getmethods__["bFilled"] = _EUSignCP.EU_CERT_INFO_EX_bFilled_get
    if _newclass:
        bFilled = _swig_property(_EUSignCP.EU_CERT_INFO_EX_bFilled_get, _EUSignCP.EU_CERT_INFO_EX_bFilled_set)
    __swig_setmethods__["dwVersion"] = _EUSignCP.EU_CERT_INFO_EX_dwVersion_set
    __swig_getmethods__["dwVersion"] = _EUSignCP.EU_CERT_INFO_EX_dwVersion_get
    if _newclass:
        dwVersion = _swig_property(_EUSignCP.EU_CERT_INFO_EX_dwVersion_get, _EUSignCP.EU_CERT_INFO_EX_dwVersion_set)
    __swig_setmethods__["pszIssuer"] = _EUSignCP.EU_CERT_INFO_EX_pszIssuer_set
    __swig_getmethods__["pszIssuer"] = _EUSignCP.EU_CERT_INFO_EX_pszIssuer_get
    if _newclass:
        pszIssuer = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszIssuer_get, _EUSignCP.EU_CERT_INFO_EX_pszIssuer_set)
    __swig_setmethods__["pszIssuerCN"] = _EUSignCP.EU_CERT_INFO_EX_pszIssuerCN_set
    __swig_getmethods__["pszIssuerCN"] = _EUSignCP.EU_CERT_INFO_EX_pszIssuerCN_get
    if _newclass:
        pszIssuerCN = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszIssuerCN_get, _EUSignCP.EU_CERT_INFO_EX_pszIssuerCN_set)
    __swig_setmethods__["pszSerial"] = _EUSignCP.EU_CERT_INFO_EX_pszSerial_set
    __swig_getmethods__["pszSerial"] = _EUSignCP.EU_CERT_INFO_EX_pszSerial_get
    if _newclass:
        pszSerial = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszSerial_get, _EUSignCP.EU_CERT_INFO_EX_pszSerial_set)
    __swig_setmethods__["pszSubject"] = _EUSignCP.EU_CERT_INFO_EX_pszSubject_set
    __swig_getmethods__["pszSubject"] = _EUSignCP.EU_CERT_INFO_EX_pszSubject_get
    if _newclass:
        pszSubject = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszSubject_get, _EUSignCP.EU_CERT_INFO_EX_pszSubject_set)
    __swig_setmethods__["pszSubjCN"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjCN_set
    __swig_getmethods__["pszSubjCN"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjCN_get
    if _newclass:
        pszSubjCN = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszSubjCN_get, _EUSignCP.EU_CERT_INFO_EX_pszSubjCN_set)
    __swig_setmethods__["pszSubjOrg"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjOrg_set
    __swig_getmethods__["pszSubjOrg"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjOrg_get
    if _newclass:
        pszSubjOrg = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszSubjOrg_get, _EUSignCP.EU_CERT_INFO_EX_pszSubjOrg_set)
    __swig_setmethods__["pszSubjOrgUnit"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjOrgUnit_set
    __swig_getmethods__["pszSubjOrgUnit"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjOrgUnit_get
    if _newclass:
        pszSubjOrgUnit = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszSubjOrgUnit_get, _EUSignCP.EU_CERT_INFO_EX_pszSubjOrgUnit_set)
    __swig_setmethods__["pszSubjTitle"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjTitle_set
    __swig_getmethods__["pszSubjTitle"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjTitle_get
    if _newclass:
        pszSubjTitle = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszSubjTitle_get, _EUSignCP.EU_CERT_INFO_EX_pszSubjTitle_set)
    __swig_setmethods__["pszSubjState"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjState_set
    __swig_getmethods__["pszSubjState"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjState_get
    if _newclass:
        pszSubjState = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszSubjState_get, _EUSignCP.EU_CERT_INFO_EX_pszSubjState_set)
    __swig_setmethods__["pszSubjLocality"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjLocality_set
    __swig_getmethods__["pszSubjLocality"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjLocality_get
    if _newclass:
        pszSubjLocality = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszSubjLocality_get, _EUSignCP.EU_CERT_INFO_EX_pszSubjLocality_set)
    __swig_setmethods__["pszSubjFullName"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjFullName_set
    __swig_getmethods__["pszSubjFullName"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjFullName_get
    if _newclass:
        pszSubjFullName = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszSubjFullName_get, _EUSignCP.EU_CERT_INFO_EX_pszSubjFullName_set)
    __swig_setmethods__["pszSubjAddress"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjAddress_set
    __swig_getmethods__["pszSubjAddress"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjAddress_get
    if _newclass:
        pszSubjAddress = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszSubjAddress_get, _EUSignCP.EU_CERT_INFO_EX_pszSubjAddress_set)
    __swig_setmethods__["pszSubjPhone"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjPhone_set
    __swig_getmethods__["pszSubjPhone"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjPhone_get
    if _newclass:
        pszSubjPhone = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszSubjPhone_get, _EUSignCP.EU_CERT_INFO_EX_pszSubjPhone_set)
    __swig_setmethods__["pszSubjEMail"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjEMail_set
    __swig_getmethods__["pszSubjEMail"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjEMail_get
    if _newclass:
        pszSubjEMail = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszSubjEMail_get, _EUSignCP.EU_CERT_INFO_EX_pszSubjEMail_set)
    __swig_setmethods__["pszSubjDNS"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjDNS_set
    __swig_getmethods__["pszSubjDNS"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjDNS_get
    if _newclass:
        pszSubjDNS = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszSubjDNS_get, _EUSignCP.EU_CERT_INFO_EX_pszSubjDNS_set)
    __swig_setmethods__["pszSubjEDRPOUCode"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjEDRPOUCode_set
    __swig_getmethods__["pszSubjEDRPOUCode"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjEDRPOUCode_get
    if _newclass:
        pszSubjEDRPOUCode = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszSubjEDRPOUCode_get, _EUSignCP.EU_CERT_INFO_EX_pszSubjEDRPOUCode_set)
    __swig_setmethods__["pszSubjDRFOCode"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjDRFOCode_set
    __swig_getmethods__["pszSubjDRFOCode"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjDRFOCode_get
    if _newclass:
        pszSubjDRFOCode = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszSubjDRFOCode_get, _EUSignCP.EU_CERT_INFO_EX_pszSubjDRFOCode_set)
    __swig_setmethods__["pszSubjNBUCode"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjNBUCode_set
    __swig_getmethods__["pszSubjNBUCode"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjNBUCode_get
    if _newclass:
        pszSubjNBUCode = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszSubjNBUCode_get, _EUSignCP.EU_CERT_INFO_EX_pszSubjNBUCode_set)
    __swig_setmethods__["pszSubjSPFMCode"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjSPFMCode_set
    __swig_getmethods__["pszSubjSPFMCode"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjSPFMCode_get
    if _newclass:
        pszSubjSPFMCode = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszSubjSPFMCode_get, _EUSignCP.EU_CERT_INFO_EX_pszSubjSPFMCode_set)
    __swig_setmethods__["pszSubjOCode"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjOCode_set
    __swig_getmethods__["pszSubjOCode"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjOCode_get
    if _newclass:
        pszSubjOCode = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszSubjOCode_get, _EUSignCP.EU_CERT_INFO_EX_pszSubjOCode_set)
    __swig_setmethods__["pszSubjOUCode"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjOUCode_set
    __swig_getmethods__["pszSubjOUCode"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjOUCode_get
    if _newclass:
        pszSubjOUCode = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszSubjOUCode_get, _EUSignCP.EU_CERT_INFO_EX_pszSubjOUCode_set)
    __swig_setmethods__["pszSubjUserCode"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjUserCode_set
    __swig_getmethods__["pszSubjUserCode"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjUserCode_get
    if _newclass:
        pszSubjUserCode = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszSubjUserCode_get, _EUSignCP.EU_CERT_INFO_EX_pszSubjUserCode_set)
    __swig_setmethods__["stCertBeginTime"] = _EUSignCP.EU_CERT_INFO_EX_stCertBeginTime_set
    __swig_getmethods__["stCertBeginTime"] = _EUSignCP.EU_CERT_INFO_EX_stCertBeginTime_get
    if _newclass:
        stCertBeginTime = _swig_property(_EUSignCP.EU_CERT_INFO_EX_stCertBeginTime_get, _EUSignCP.EU_CERT_INFO_EX_stCertBeginTime_set)
    __swig_setmethods__["stCertEndTime"] = _EUSignCP.EU_CERT_INFO_EX_stCertEndTime_set
    __swig_getmethods__["stCertEndTime"] = _EUSignCP.EU_CERT_INFO_EX_stCertEndTime_get
    if _newclass:
        stCertEndTime = _swig_property(_EUSignCP.EU_CERT_INFO_EX_stCertEndTime_get, _EUSignCP.EU_CERT_INFO_EX_stCertEndTime_set)
    __swig_setmethods__["bPrivKeyTimes"] = _EUSignCP.EU_CERT_INFO_EX_bPrivKeyTimes_set
    __swig_getmethods__["bPrivKeyTimes"] = _EUSignCP.EU_CERT_INFO_EX_bPrivKeyTimes_get
    if _newclass:
        bPrivKeyTimes = _swig_property(_EUSignCP.EU_CERT_INFO_EX_bPrivKeyTimes_get, _EUSignCP.EU_CERT_INFO_EX_bPrivKeyTimes_set)
    __swig_setmethods__["stPrivKeyBeginTime"] = _EUSignCP.EU_CERT_INFO_EX_stPrivKeyBeginTime_set
    __swig_getmethods__["stPrivKeyBeginTime"] = _EUSignCP.EU_CERT_INFO_EX_stPrivKeyBeginTime_get
    if _newclass:
        stPrivKeyBeginTime = _swig_property(_EUSignCP.EU_CERT_INFO_EX_stPrivKeyBeginTime_get, _EUSignCP.EU_CERT_INFO_EX_stPrivKeyBeginTime_set)
    __swig_setmethods__["stPrivKeyEndTime"] = _EUSignCP.EU_CERT_INFO_EX_stPrivKeyEndTime_set
    __swig_getmethods__["stPrivKeyEndTime"] = _EUSignCP.EU_CERT_INFO_EX_stPrivKeyEndTime_get
    if _newclass:
        stPrivKeyEndTime = _swig_property(_EUSignCP.EU_CERT_INFO_EX_stPrivKeyEndTime_get, _EUSignCP.EU_CERT_INFO_EX_stPrivKeyEndTime_set)
    __swig_setmethods__["dwPublicKeyBits"] = _EUSignCP.EU_CERT_INFO_EX_dwPublicKeyBits_set
    __swig_getmethods__["dwPublicKeyBits"] = _EUSignCP.EU_CERT_INFO_EX_dwPublicKeyBits_get
    if _newclass:
        dwPublicKeyBits = _swig_property(_EUSignCP.EU_CERT_INFO_EX_dwPublicKeyBits_get, _EUSignCP.EU_CERT_INFO_EX_dwPublicKeyBits_set)
    __swig_setmethods__["pszPublicKey"] = _EUSignCP.EU_CERT_INFO_EX_pszPublicKey_set
    __swig_getmethods__["pszPublicKey"] = _EUSignCP.EU_CERT_INFO_EX_pszPublicKey_get
    if _newclass:
        pszPublicKey = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszPublicKey_get, _EUSignCP.EU_CERT_INFO_EX_pszPublicKey_set)
    __swig_setmethods__["pszPublicKeyID"] = _EUSignCP.EU_CERT_INFO_EX_pszPublicKeyID_set
    __swig_getmethods__["pszPublicKeyID"] = _EUSignCP.EU_CERT_INFO_EX_pszPublicKeyID_get
    if _newclass:
        pszPublicKeyID = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszPublicKeyID_get, _EUSignCP.EU_CERT_INFO_EX_pszPublicKeyID_set)
    __swig_setmethods__["pszIssuerPublicKeyID"] = _EUSignCP.EU_CERT_INFO_EX_pszIssuerPublicKeyID_set
    __swig_getmethods__["pszIssuerPublicKeyID"] = _EUSignCP.EU_CERT_INFO_EX_pszIssuerPublicKeyID_get
    if _newclass:
        pszIssuerPublicKeyID = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszIssuerPublicKeyID_get, _EUSignCP.EU_CERT_INFO_EX_pszIssuerPublicKeyID_set)
    __swig_setmethods__["pszKeyUsage"] = _EUSignCP.EU_CERT_INFO_EX_pszKeyUsage_set
    __swig_getmethods__["pszKeyUsage"] = _EUSignCP.EU_CERT_INFO_EX_pszKeyUsage_get
    if _newclass:
        pszKeyUsage = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszKeyUsage_get, _EUSignCP.EU_CERT_INFO_EX_pszKeyUsage_set)
    __swig_setmethods__["pszExtKeyUsages"] = _EUSignCP.EU_CERT_INFO_EX_pszExtKeyUsages_set
    __swig_getmethods__["pszExtKeyUsages"] = _EUSignCP.EU_CERT_INFO_EX_pszExtKeyUsages_get
    if _newclass:
        pszExtKeyUsages = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszExtKeyUsages_get, _EUSignCP.EU_CERT_INFO_EX_pszExtKeyUsages_set)
    __swig_setmethods__["pszPolicies"] = _EUSignCP.EU_CERT_INFO_EX_pszPolicies_set
    __swig_getmethods__["pszPolicies"] = _EUSignCP.EU_CERT_INFO_EX_pszPolicies_get
    if _newclass:
        pszPolicies = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszPolicies_get, _EUSignCP.EU_CERT_INFO_EX_pszPolicies_set)
    __swig_setmethods__["pszCRLDistribPoint1"] = _EUSignCP.EU_CERT_INFO_EX_pszCRLDistribPoint1_set
    __swig_getmethods__["pszCRLDistribPoint1"] = _EUSignCP.EU_CERT_INFO_EX_pszCRLDistribPoint1_get
    if _newclass:
        pszCRLDistribPoint1 = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszCRLDistribPoint1_get, _EUSignCP.EU_CERT_INFO_EX_pszCRLDistribPoint1_set)
    __swig_setmethods__["pszCRLDistribPoint2"] = _EUSignCP.EU_CERT_INFO_EX_pszCRLDistribPoint2_set
    __swig_getmethods__["pszCRLDistribPoint2"] = _EUSignCP.EU_CERT_INFO_EX_pszCRLDistribPoint2_get
    if _newclass:
        pszCRLDistribPoint2 = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszCRLDistribPoint2_get, _EUSignCP.EU_CERT_INFO_EX_pszCRLDistribPoint2_set)
    __swig_setmethods__["bPowerCert"] = _EUSignCP.EU_CERT_INFO_EX_bPowerCert_set
    __swig_getmethods__["bPowerCert"] = _EUSignCP.EU_CERT_INFO_EX_bPowerCert_get
    if _newclass:
        bPowerCert = _swig_property(_EUSignCP.EU_CERT_INFO_EX_bPowerCert_get, _EUSignCP.EU_CERT_INFO_EX_bPowerCert_set)
    __swig_setmethods__["bSubjType"] = _EUSignCP.EU_CERT_INFO_EX_bSubjType_set
    __swig_getmethods__["bSubjType"] = _EUSignCP.EU_CERT_INFO_EX_bSubjType_get
    if _newclass:
        bSubjType = _swig_property(_EUSignCP.EU_CERT_INFO_EX_bSubjType_get, _EUSignCP.EU_CERT_INFO_EX_bSubjType_set)
    __swig_setmethods__["bSubjCA"] = _EUSignCP.EU_CERT_INFO_EX_bSubjCA_set
    __swig_getmethods__["bSubjCA"] = _EUSignCP.EU_CERT_INFO_EX_bSubjCA_get
    if _newclass:
        bSubjCA = _swig_property(_EUSignCP.EU_CERT_INFO_EX_bSubjCA_get, _EUSignCP.EU_CERT_INFO_EX_bSubjCA_set)
    __swig_setmethods__["iChainLength"] = _EUSignCP.EU_CERT_INFO_EX_iChainLength_set
    __swig_getmethods__["iChainLength"] = _EUSignCP.EU_CERT_INFO_EX_iChainLength_get
    if _newclass:
        iChainLength = _swig_property(_EUSignCP.EU_CERT_INFO_EX_iChainLength_get, _EUSignCP.EU_CERT_INFO_EX_iChainLength_set)
    __swig_setmethods__["pszUPN"] = _EUSignCP.EU_CERT_INFO_EX_pszUPN_set
    __swig_getmethods__["pszUPN"] = _EUSignCP.EU_CERT_INFO_EX_pszUPN_get
    if _newclass:
        pszUPN = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszUPN_get, _EUSignCP.EU_CERT_INFO_EX_pszUPN_set)
    __swig_setmethods__["dwPublicKeyType"] = _EUSignCP.EU_CERT_INFO_EX_dwPublicKeyType_set
    __swig_getmethods__["dwPublicKeyType"] = _EUSignCP.EU_CERT_INFO_EX_dwPublicKeyType_get
    if _newclass:
        dwPublicKeyType = _swig_property(_EUSignCP.EU_CERT_INFO_EX_dwPublicKeyType_get, _EUSignCP.EU_CERT_INFO_EX_dwPublicKeyType_set)
    __swig_setmethods__["dwKeyUsage"] = _EUSignCP.EU_CERT_INFO_EX_dwKeyUsage_set
    __swig_getmethods__["dwKeyUsage"] = _EUSignCP.EU_CERT_INFO_EX_dwKeyUsage_get
    if _newclass:
        dwKeyUsage = _swig_property(_EUSignCP.EU_CERT_INFO_EX_dwKeyUsage_get, _EUSignCP.EU_CERT_INFO_EX_dwKeyUsage_set)
    __swig_setmethods__["pszRSAModul"] = _EUSignCP.EU_CERT_INFO_EX_pszRSAModul_set
    __swig_getmethods__["pszRSAModul"] = _EUSignCP.EU_CERT_INFO_EX_pszRSAModul_get
    if _newclass:
        pszRSAModul = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszRSAModul_get, _EUSignCP.EU_CERT_INFO_EX_pszRSAModul_set)
    __swig_setmethods__["pszRSAExponent"] = _EUSignCP.EU_CERT_INFO_EX_pszRSAExponent_set
    __swig_getmethods__["pszRSAExponent"] = _EUSignCP.EU_CERT_INFO_EX_pszRSAExponent_get
    if _newclass:
        pszRSAExponent = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszRSAExponent_get, _EUSignCP.EU_CERT_INFO_EX_pszRSAExponent_set)
    __swig_setmethods__["pszOCSPAccessInfo"] = _EUSignCP.EU_CERT_INFO_EX_pszOCSPAccessInfo_set
    __swig_getmethods__["pszOCSPAccessInfo"] = _EUSignCP.EU_CERT_INFO_EX_pszOCSPAccessInfo_get
    if _newclass:
        pszOCSPAccessInfo = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszOCSPAccessInfo_get, _EUSignCP.EU_CERT_INFO_EX_pszOCSPAccessInfo_set)
    __swig_setmethods__["pszIssuerAccessInfo"] = _EUSignCP.EU_CERT_INFO_EX_pszIssuerAccessInfo_set
    __swig_getmethods__["pszIssuerAccessInfo"] = _EUSignCP.EU_CERT_INFO_EX_pszIssuerAccessInfo_get
    if _newclass:
        pszIssuerAccessInfo = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszIssuerAccessInfo_get, _EUSignCP.EU_CERT_INFO_EX_pszIssuerAccessInfo_set)
    __swig_setmethods__["pszTSPAccessInfo"] = _EUSignCP.EU_CERT_INFO_EX_pszTSPAccessInfo_set
    __swig_getmethods__["pszTSPAccessInfo"] = _EUSignCP.EU_CERT_INFO_EX_pszTSPAccessInfo_get
    if _newclass:
        pszTSPAccessInfo = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszTSPAccessInfo_get, _EUSignCP.EU_CERT_INFO_EX_pszTSPAccessInfo_set)
    __swig_setmethods__["bLimitValueAvailable"] = _EUSignCP.EU_CERT_INFO_EX_bLimitValueAvailable_set
    __swig_getmethods__["bLimitValueAvailable"] = _EUSignCP.EU_CERT_INFO_EX_bLimitValueAvailable_get
    if _newclass:
        bLimitValueAvailable = _swig_property(_EUSignCP.EU_CERT_INFO_EX_bLimitValueAvailable_get, _EUSignCP.EU_CERT_INFO_EX_bLimitValueAvailable_set)
    __swig_setmethods__["dwLimitValue"] = _EUSignCP.EU_CERT_INFO_EX_dwLimitValue_set
    __swig_getmethods__["dwLimitValue"] = _EUSignCP.EU_CERT_INFO_EX_dwLimitValue_get
    if _newclass:
        dwLimitValue = _swig_property(_EUSignCP.EU_CERT_INFO_EX_dwLimitValue_get, _EUSignCP.EU_CERT_INFO_EX_dwLimitValue_set)
    __swig_setmethods__["pszLimitValueCurrency"] = _EUSignCP.EU_CERT_INFO_EX_pszLimitValueCurrency_set
    __swig_getmethods__["pszLimitValueCurrency"] = _EUSignCP.EU_CERT_INFO_EX_pszLimitValueCurrency_get
    if _newclass:
        pszLimitValueCurrency = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszLimitValueCurrency_get, _EUSignCP.EU_CERT_INFO_EX_pszLimitValueCurrency_set)
    __swig_setmethods__["dwSubjType"] = _EUSignCP.EU_CERT_INFO_EX_dwSubjType_set
    __swig_getmethods__["dwSubjType"] = _EUSignCP.EU_CERT_INFO_EX_dwSubjType_get
    if _newclass:
        dwSubjType = _swig_property(_EUSignCP.EU_CERT_INFO_EX_dwSubjType_get, _EUSignCP.EU_CERT_INFO_EX_dwSubjType_set)
    __swig_setmethods__["dwSubjSubType"] = _EUSignCP.EU_CERT_INFO_EX_dwSubjSubType_set
    __swig_getmethods__["dwSubjSubType"] = _EUSignCP.EU_CERT_INFO_EX_dwSubjSubType_get
    if _newclass:
        dwSubjSubType = _swig_property(_EUSignCP.EU_CERT_INFO_EX_dwSubjSubType_get, _EUSignCP.EU_CERT_INFO_EX_dwSubjSubType_set)
    __swig_setmethods__["pszSubjUNZR"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjUNZR_set
    __swig_getmethods__["pszSubjUNZR"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjUNZR_get
    if _newclass:
        pszSubjUNZR = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszSubjUNZR_get, _EUSignCP.EU_CERT_INFO_EX_pszSubjUNZR_set)
    __swig_setmethods__["pszSubjCountry"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjCountry_set
    __swig_getmethods__["pszSubjCountry"] = _EUSignCP.EU_CERT_INFO_EX_pszSubjCountry_get
    if _newclass:
        pszSubjCountry = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszSubjCountry_get, _EUSignCP.EU_CERT_INFO_EX_pszSubjCountry_set)
    __swig_setmethods__["pszFingerprint"] = _EUSignCP.EU_CERT_INFO_EX_pszFingerprint_set
    __swig_getmethods__["pszFingerprint"] = _EUSignCP.EU_CERT_INFO_EX_pszFingerprint_get
    if _newclass:
        pszFingerprint = _swig_property(_EUSignCP.EU_CERT_INFO_EX_pszFingerprint_get, _EUSignCP.EU_CERT_INFO_EX_pszFingerprint_set)

    def __init__(self):
        this = _EUSignCP.new_EU_CERT_INFO_EX()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _EUSignCP.delete_EU_CERT_INFO_EX
    __del__ = lambda self: None
EU_CERT_INFO_EX_swigregister = _EUSignCP.EU_CERT_INFO_EX_swigregister
EU_CERT_INFO_EX_swigregister(EU_CERT_INFO_EX)

class EU_CRL_DETAILED_INFO(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, EU_CRL_DETAILED_INFO, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, EU_CRL_DETAILED_INFO, name)
    __repr__ = _swig_repr
    __swig_setmethods__["bFilled"] = _EUSignCP.EU_CRL_DETAILED_INFO_bFilled_set
    __swig_getmethods__["bFilled"] = _EUSignCP.EU_CRL_DETAILED_INFO_bFilled_get
    if _newclass:
        bFilled = _swig_property(_EUSignCP.EU_CRL_DETAILED_INFO_bFilled_get, _EUSignCP.EU_CRL_DETAILED_INFO_bFilled_set)
    __swig_setmethods__["dwVersion"] = _EUSignCP.EU_CRL_DETAILED_INFO_dwVersion_set
    __swig_getmethods__["dwVersion"] = _EUSignCP.EU_CRL_DETAILED_INFO_dwVersion_get
    if _newclass:
        dwVersion = _swig_property(_EUSignCP.EU_CRL_DETAILED_INFO_dwVersion_get, _EUSignCP.EU_CRL_DETAILED_INFO_dwVersion_set)
    __swig_setmethods__["pszIssuer"] = _EUSignCP.EU_CRL_DETAILED_INFO_pszIssuer_set
    __swig_getmethods__["pszIssuer"] = _EUSignCP.EU_CRL_DETAILED_INFO_pszIssuer_get
    if _newclass:
        pszIssuer = _swig_property(_EUSignCP.EU_CRL_DETAILED_INFO_pszIssuer_get, _EUSignCP.EU_CRL_DETAILED_INFO_pszIssuer_set)
    __swig_setmethods__["pszIssuerCN"] = _EUSignCP.EU_CRL_DETAILED_INFO_pszIssuerCN_set
    __swig_getmethods__["pszIssuerCN"] = _EUSignCP.EU_CRL_DETAILED_INFO_pszIssuerCN_get
    if _newclass:
        pszIssuerCN = _swig_property(_EUSignCP.EU_CRL_DETAILED_INFO_pszIssuerCN_get, _EUSignCP.EU_CRL_DETAILED_INFO_pszIssuerCN_set)
    __swig_setmethods__["pszIssuerPublicKeyID"] = _EUSignCP.EU_CRL_DETAILED_INFO_pszIssuerPublicKeyID_set
    __swig_getmethods__["pszIssuerPublicKeyID"] = _EUSignCP.EU_CRL_DETAILED_INFO_pszIssuerPublicKeyID_get
    if _newclass:
        pszIssuerPublicKeyID = _swig_property(_EUSignCP.EU_CRL_DETAILED_INFO_pszIssuerPublicKeyID_get, _EUSignCP.EU_CRL_DETAILED_INFO_pszIssuerPublicKeyID_set)
    __swig_setmethods__["dwCRLNumber"] = _EUSignCP.EU_CRL_DETAILED_INFO_dwCRLNumber_set
    __swig_getmethods__["dwCRLNumber"] = _EUSignCP.EU_CRL_DETAILED_INFO_dwCRLNumber_get
    if _newclass:
        dwCRLNumber = _swig_property(_EUSignCP.EU_CRL_DETAILED_INFO_dwCRLNumber_get, _EUSignCP.EU_CRL_DETAILED_INFO_dwCRLNumber_set)
    __swig_setmethods__["stThisUpdate"] = _EUSignCP.EU_CRL_DETAILED_INFO_stThisUpdate_set
    __swig_getmethods__["stThisUpdate"] = _EUSignCP.EU_CRL_DETAILED_INFO_stThisUpdate_get
    if _newclass:
        stThisUpdate = _swig_property(_EUSignCP.EU_CRL_DETAILED_INFO_stThisUpdate_get, _EUSignCP.EU_CRL_DETAILED_INFO_stThisUpdate_set)
    __swig_setmethods__["stNextUpdate"] = _EUSignCP.EU_CRL_DETAILED_INFO_stNextUpdate_set
    __swig_getmethods__["stNextUpdate"] = _EUSignCP.EU_CRL_DETAILED_INFO_stNextUpdate_get
    if _newclass:
        stNextUpdate = _swig_property(_EUSignCP.EU_CRL_DETAILED_INFO_stNextUpdate_get, _EUSignCP.EU_CRL_DETAILED_INFO_stNextUpdate_set)
    __swig_setmethods__["dwRevokedItemsCount"] = _EUSignCP.EU_CRL_DETAILED_INFO_dwRevokedItemsCount_set
    __swig_getmethods__["dwRevokedItemsCount"] = _EUSignCP.EU_CRL_DETAILED_INFO_dwRevokedItemsCount_get
    if _newclass:
        dwRevokedItemsCount = _swig_property(_EUSignCP.EU_CRL_DETAILED_INFO_dwRevokedItemsCount_get, _EUSignCP.EU_CRL_DETAILED_INFO_dwRevokedItemsCount_set)

    def __init__(self):
        this = _EUSignCP.new_EU_CRL_DETAILED_INFO()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _EUSignCP.delete_EU_CRL_DETAILED_INFO
    __del__ = lambda self: None
EU_CRL_DETAILED_INFO_swigregister = _EUSignCP.EU_CRL_DETAILED_INFO_swigregister
EU_CRL_DETAILED_INFO_swigregister(EU_CRL_DETAILED_INFO)

class EU_CERTIFICATES(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, EU_CERTIFICATES, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, EU_CERTIFICATES, name)
    __repr__ = _swig_repr
    __swig_setmethods__["dwCount"] = _EUSignCP.EU_CERTIFICATES_dwCount_set
    __swig_getmethods__["dwCount"] = _EUSignCP.EU_CERTIFICATES_dwCount_get
    if _newclass:
        dwCount = _swig_property(_EUSignCP.EU_CERTIFICATES_dwCount_get, _EUSignCP.EU_CERTIFICATES_dwCount_set)
    __swig_setmethods__["ppCertificates"] = _EUSignCP.EU_CERTIFICATES_ppCertificates_set
    __swig_getmethods__["ppCertificates"] = _EUSignCP.EU_CERTIFICATES_ppCertificates_get
    if _newclass:
        ppCertificates = _swig_property(_EUSignCP.EU_CERTIFICATES_ppCertificates_get, _EUSignCP.EU_CERTIFICATES_ppCertificates_set)

    def __init__(self):
        this = _EUSignCP.new_EU_CERTIFICATES()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _EUSignCP.delete_EU_CERTIFICATES
    __del__ = lambda self: None
EU_CERTIFICATES_swigregister = _EUSignCP.EU_CERTIFICATES_swigregister
EU_CERTIFICATES_swigregister(EU_CERTIFICATES)

class EU_CR_INFO(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, EU_CR_INFO, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, EU_CR_INFO, name)
    __repr__ = _swig_repr
    __swig_setmethods__["bFilled"] = _EUSignCP.EU_CR_INFO_bFilled_set
    __swig_getmethods__["bFilled"] = _EUSignCP.EU_CR_INFO_bFilled_get
    if _newclass:
        bFilled = _swig_property(_EUSignCP.EU_CR_INFO_bFilled_get, _EUSignCP.EU_CR_INFO_bFilled_set)
    __swig_setmethods__["dwVersion"] = _EUSignCP.EU_CR_INFO_dwVersion_set
    __swig_getmethods__["dwVersion"] = _EUSignCP.EU_CR_INFO_dwVersion_get
    if _newclass:
        dwVersion = _swig_property(_EUSignCP.EU_CR_INFO_dwVersion_get, _EUSignCP.EU_CR_INFO_dwVersion_set)
    __swig_setmethods__["bSimple"] = _EUSignCP.EU_CR_INFO_bSimple_set
    __swig_getmethods__["bSimple"] = _EUSignCP.EU_CR_INFO_bSimple_get
    if _newclass:
        bSimple = _swig_property(_EUSignCP.EU_CR_INFO_bSimple_get, _EUSignCP.EU_CR_INFO_bSimple_set)
    __swig_setmethods__["pszSubject"] = _EUSignCP.EU_CR_INFO_pszSubject_set
    __swig_getmethods__["pszSubject"] = _EUSignCP.EU_CR_INFO_pszSubject_get
    if _newclass:
        pszSubject = _swig_property(_EUSignCP.EU_CR_INFO_pszSubject_get, _EUSignCP.EU_CR_INFO_pszSubject_set)
    __swig_setmethods__["pszSubjCN"] = _EUSignCP.EU_CR_INFO_pszSubjCN_set
    __swig_getmethods__["pszSubjCN"] = _EUSignCP.EU_CR_INFO_pszSubjCN_get
    if _newclass:
        pszSubjCN = _swig_property(_EUSignCP.EU_CR_INFO_pszSubjCN_get, _EUSignCP.EU_CR_INFO_pszSubjCN_set)
    __swig_setmethods__["pszSubjOrg"] = _EUSignCP.EU_CR_INFO_pszSubjOrg_set
    __swig_getmethods__["pszSubjOrg"] = _EUSignCP.EU_CR_INFO_pszSubjOrg_get
    if _newclass:
        pszSubjOrg = _swig_property(_EUSignCP.EU_CR_INFO_pszSubjOrg_get, _EUSignCP.EU_CR_INFO_pszSubjOrg_set)
    __swig_setmethods__["pszSubjOrgUnit"] = _EUSignCP.EU_CR_INFO_pszSubjOrgUnit_set
    __swig_getmethods__["pszSubjOrgUnit"] = _EUSignCP.EU_CR_INFO_pszSubjOrgUnit_get
    if _newclass:
        pszSubjOrgUnit = _swig_property(_EUSignCP.EU_CR_INFO_pszSubjOrgUnit_get, _EUSignCP.EU_CR_INFO_pszSubjOrgUnit_set)
    __swig_setmethods__["pszSubjTitle"] = _EUSignCP.EU_CR_INFO_pszSubjTitle_set
    __swig_getmethods__["pszSubjTitle"] = _EUSignCP.EU_CR_INFO_pszSubjTitle_get
    if _newclass:
        pszSubjTitle = _swig_property(_EUSignCP.EU_CR_INFO_pszSubjTitle_get, _EUSignCP.EU_CR_INFO_pszSubjTitle_set)
    __swig_setmethods__["pszSubjState"] = _EUSignCP.EU_CR_INFO_pszSubjState_set
    __swig_getmethods__["pszSubjState"] = _EUSignCP.EU_CR_INFO_pszSubjState_get
    if _newclass:
        pszSubjState = _swig_property(_EUSignCP.EU_CR_INFO_pszSubjState_get, _EUSignCP.EU_CR_INFO_pszSubjState_set)
    __swig_setmethods__["pszSubjLocality"] = _EUSignCP.EU_CR_INFO_pszSubjLocality_set
    __swig_getmethods__["pszSubjLocality"] = _EUSignCP.EU_CR_INFO_pszSubjLocality_get
    if _newclass:
        pszSubjLocality = _swig_property(_EUSignCP.EU_CR_INFO_pszSubjLocality_get, _EUSignCP.EU_CR_INFO_pszSubjLocality_set)
    __swig_setmethods__["pszSubjFullName"] = _EUSignCP.EU_CR_INFO_pszSubjFullName_set
    __swig_getmethods__["pszSubjFullName"] = _EUSignCP.EU_CR_INFO_pszSubjFullName_get
    if _newclass:
        pszSubjFullName = _swig_property(_EUSignCP.EU_CR_INFO_pszSubjFullName_get, _EUSignCP.EU_CR_INFO_pszSubjFullName_set)
    __swig_setmethods__["pszSubjAddress"] = _EUSignCP.EU_CR_INFO_pszSubjAddress_set
    __swig_getmethods__["pszSubjAddress"] = _EUSignCP.EU_CR_INFO_pszSubjAddress_get
    if _newclass:
        pszSubjAddress = _swig_property(_EUSignCP.EU_CR_INFO_pszSubjAddress_get, _EUSignCP.EU_CR_INFO_pszSubjAddress_set)
    __swig_setmethods__["pszSubjPhone"] = _EUSignCP.EU_CR_INFO_pszSubjPhone_set
    __swig_getmethods__["pszSubjPhone"] = _EUSignCP.EU_CR_INFO_pszSubjPhone_get
    if _newclass:
        pszSubjPhone = _swig_property(_EUSignCP.EU_CR_INFO_pszSubjPhone_get, _EUSignCP.EU_CR_INFO_pszSubjPhone_set)
    __swig_setmethods__["pszSubjEMail"] = _EUSignCP.EU_CR_INFO_pszSubjEMail_set
    __swig_getmethods__["pszSubjEMail"] = _EUSignCP.EU_CR_INFO_pszSubjEMail_get
    if _newclass:
        pszSubjEMail = _swig_property(_EUSignCP.EU_CR_INFO_pszSubjEMail_get, _EUSignCP.EU_CR_INFO_pszSubjEMail_set)
    __swig_setmethods__["pszSubjDNS"] = _EUSignCP.EU_CR_INFO_pszSubjDNS_set
    __swig_getmethods__["pszSubjDNS"] = _EUSignCP.EU_CR_INFO_pszSubjDNS_get
    if _newclass:
        pszSubjDNS = _swig_property(_EUSignCP.EU_CR_INFO_pszSubjDNS_get, _EUSignCP.EU_CR_INFO_pszSubjDNS_set)
    __swig_setmethods__["pszSubjEDRPOUCode"] = _EUSignCP.EU_CR_INFO_pszSubjEDRPOUCode_set
    __swig_getmethods__["pszSubjEDRPOUCode"] = _EUSignCP.EU_CR_INFO_pszSubjEDRPOUCode_get
    if _newclass:
        pszSubjEDRPOUCode = _swig_property(_EUSignCP.EU_CR_INFO_pszSubjEDRPOUCode_get, _EUSignCP.EU_CR_INFO_pszSubjEDRPOUCode_set)
    __swig_setmethods__["pszSubjDRFOCode"] = _EUSignCP.EU_CR_INFO_pszSubjDRFOCode_set
    __swig_getmethods__["pszSubjDRFOCode"] = _EUSignCP.EU_CR_INFO_pszSubjDRFOCode_get
    if _newclass:
        pszSubjDRFOCode = _swig_property(_EUSignCP.EU_CR_INFO_pszSubjDRFOCode_get, _EUSignCP.EU_CR_INFO_pszSubjDRFOCode_set)
    __swig_setmethods__["pszSubjNBUCode"] = _EUSignCP.EU_CR_INFO_pszSubjNBUCode_set
    __swig_getmethods__["pszSubjNBUCode"] = _EUSignCP.EU_CR_INFO_pszSubjNBUCode_get
    if _newclass:
        pszSubjNBUCode = _swig_property(_EUSignCP.EU_CR_INFO_pszSubjNBUCode_get, _EUSignCP.EU_CR_INFO_pszSubjNBUCode_set)
    __swig_setmethods__["pszSubjSPFMCode"] = _EUSignCP.EU_CR_INFO_pszSubjSPFMCode_set
    __swig_getmethods__["pszSubjSPFMCode"] = _EUSignCP.EU_CR_INFO_pszSubjSPFMCode_get
    if _newclass:
        pszSubjSPFMCode = _swig_property(_EUSignCP.EU_CR_INFO_pszSubjSPFMCode_get, _EUSignCP.EU_CR_INFO_pszSubjSPFMCode_set)
    __swig_setmethods__["pszSubjOCode"] = _EUSignCP.EU_CR_INFO_pszSubjOCode_set
    __swig_getmethods__["pszSubjOCode"] = _EUSignCP.EU_CR_INFO_pszSubjOCode_get
    if _newclass:
        pszSubjOCode = _swig_property(_EUSignCP.EU_CR_INFO_pszSubjOCode_get, _EUSignCP.EU_CR_INFO_pszSubjOCode_set)
    __swig_setmethods__["pszSubjOUCode"] = _EUSignCP.EU_CR_INFO_pszSubjOUCode_set
    __swig_getmethods__["pszSubjOUCode"] = _EUSignCP.EU_CR_INFO_pszSubjOUCode_get
    if _newclass:
        pszSubjOUCode = _swig_property(_EUSignCP.EU_CR_INFO_pszSubjOUCode_get, _EUSignCP.EU_CR_INFO_pszSubjOUCode_set)
    __swig_setmethods__["pszSubjUserCode"] = _EUSignCP.EU_CR_INFO_pszSubjUserCode_set
    __swig_getmethods__["pszSubjUserCode"] = _EUSignCP.EU_CR_INFO_pszSubjUserCode_get
    if _newclass:
        pszSubjUserCode = _swig_property(_EUSignCP.EU_CR_INFO_pszSubjUserCode_get, _EUSignCP.EU_CR_INFO_pszSubjUserCode_set)
    __swig_setmethods__["bCertTimes"] = _EUSignCP.EU_CR_INFO_bCertTimes_set
    __swig_getmethods__["bCertTimes"] = _EUSignCP.EU_CR_INFO_bCertTimes_get
    if _newclass:
        bCertTimes = _swig_property(_EUSignCP.EU_CR_INFO_bCertTimes_get, _EUSignCP.EU_CR_INFO_bCertTimes_set)
    __swig_setmethods__["stCertBeginTime"] = _EUSignCP.EU_CR_INFO_stCertBeginTime_set
    __swig_getmethods__["stCertBeginTime"] = _EUSignCP.EU_CR_INFO_stCertBeginTime_get
    if _newclass:
        stCertBeginTime = _swig_property(_EUSignCP.EU_CR_INFO_stCertBeginTime_get, _EUSignCP.EU_CR_INFO_stCertBeginTime_set)
    __swig_setmethods__["stCertEndTime"] = _EUSignCP.EU_CR_INFO_stCertEndTime_set
    __swig_getmethods__["stCertEndTime"] = _EUSignCP.EU_CR_INFO_stCertEndTime_get
    if _newclass:
        stCertEndTime = _swig_property(_EUSignCP.EU_CR_INFO_stCertEndTime_get, _EUSignCP.EU_CR_INFO_stCertEndTime_set)
    __swig_setmethods__["bPrivKeyTimes"] = _EUSignCP.EU_CR_INFO_bPrivKeyTimes_set
    __swig_getmethods__["bPrivKeyTimes"] = _EUSignCP.EU_CR_INFO_bPrivKeyTimes_get
    if _newclass:
        bPrivKeyTimes = _swig_property(_EUSignCP.EU_CR_INFO_bPrivKeyTimes_get, _EUSignCP.EU_CR_INFO_bPrivKeyTimes_set)
    __swig_setmethods__["stPrivKeyBeginTime"] = _EUSignCP.EU_CR_INFO_stPrivKeyBeginTime_set
    __swig_getmethods__["stPrivKeyBeginTime"] = _EUSignCP.EU_CR_INFO_stPrivKeyBeginTime_get
    if _newclass:
        stPrivKeyBeginTime = _swig_property(_EUSignCP.EU_CR_INFO_stPrivKeyBeginTime_get, _EUSignCP.EU_CR_INFO_stPrivKeyBeginTime_set)
    __swig_setmethods__["stPrivKeyEndTime"] = _EUSignCP.EU_CR_INFO_stPrivKeyEndTime_set
    __swig_getmethods__["stPrivKeyEndTime"] = _EUSignCP.EU_CR_INFO_stPrivKeyEndTime_get
    if _newclass:
        stPrivKeyEndTime = _swig_property(_EUSignCP.EU_CR_INFO_stPrivKeyEndTime_get, _EUSignCP.EU_CR_INFO_stPrivKeyEndTime_set)
    __swig_setmethods__["dwPublicKeyType"] = _EUSignCP.EU_CR_INFO_dwPublicKeyType_set
    __swig_getmethods__["dwPublicKeyType"] = _EUSignCP.EU_CR_INFO_dwPublicKeyType_get
    if _newclass:
        dwPublicKeyType = _swig_property(_EUSignCP.EU_CR_INFO_dwPublicKeyType_get, _EUSignCP.EU_CR_INFO_dwPublicKeyType_set)
    __swig_setmethods__["dwPublicKeyBits"] = _EUSignCP.EU_CR_INFO_dwPublicKeyBits_set
    __swig_getmethods__["dwPublicKeyBits"] = _EUSignCP.EU_CR_INFO_dwPublicKeyBits_get
    if _newclass:
        dwPublicKeyBits = _swig_property(_EUSignCP.EU_CR_INFO_dwPublicKeyBits_get, _EUSignCP.EU_CR_INFO_dwPublicKeyBits_set)
    __swig_setmethods__["pszPublicKey"] = _EUSignCP.EU_CR_INFO_pszPublicKey_set
    __swig_getmethods__["pszPublicKey"] = _EUSignCP.EU_CR_INFO_pszPublicKey_get
    if _newclass:
        pszPublicKey = _swig_property(_EUSignCP.EU_CR_INFO_pszPublicKey_get, _EUSignCP.EU_CR_INFO_pszPublicKey_set)
    __swig_setmethods__["pszRSAModul"] = _EUSignCP.EU_CR_INFO_pszRSAModul_set
    __swig_getmethods__["pszRSAModul"] = _EUSignCP.EU_CR_INFO_pszRSAModul_get
    if _newclass:
        pszRSAModul = _swig_property(_EUSignCP.EU_CR_INFO_pszRSAModul_get, _EUSignCP.EU_CR_INFO_pszRSAModul_set)
    __swig_setmethods__["pszRSAExponent"] = _EUSignCP.EU_CR_INFO_pszRSAExponent_set
    __swig_getmethods__["pszRSAExponent"] = _EUSignCP.EU_CR_INFO_pszRSAExponent_get
    if _newclass:
        pszRSAExponent = _swig_property(_EUSignCP.EU_CR_INFO_pszRSAExponent_get, _EUSignCP.EU_CR_INFO_pszRSAExponent_set)
    __swig_setmethods__["pszPublicKeyID"] = _EUSignCP.EU_CR_INFO_pszPublicKeyID_set
    __swig_getmethods__["pszPublicKeyID"] = _EUSignCP.EU_CR_INFO_pszPublicKeyID_get
    if _newclass:
        pszPublicKeyID = _swig_property(_EUSignCP.EU_CR_INFO_pszPublicKeyID_get, _EUSignCP.EU_CR_INFO_pszPublicKeyID_set)
    __swig_setmethods__["pszExtKeyUsages"] = _EUSignCP.EU_CR_INFO_pszExtKeyUsages_set
    __swig_getmethods__["pszExtKeyUsages"] = _EUSignCP.EU_CR_INFO_pszExtKeyUsages_get
    if _newclass:
        pszExtKeyUsages = _swig_property(_EUSignCP.EU_CR_INFO_pszExtKeyUsages_get, _EUSignCP.EU_CR_INFO_pszExtKeyUsages_set)
    __swig_setmethods__["pszCRLDistribPoint1"] = _EUSignCP.EU_CR_INFO_pszCRLDistribPoint1_set
    __swig_getmethods__["pszCRLDistribPoint1"] = _EUSignCP.EU_CR_INFO_pszCRLDistribPoint1_get
    if _newclass:
        pszCRLDistribPoint1 = _swig_property(_EUSignCP.EU_CR_INFO_pszCRLDistribPoint1_get, _EUSignCP.EU_CR_INFO_pszCRLDistribPoint1_set)
    __swig_setmethods__["pszCRLDistribPoint2"] = _EUSignCP.EU_CR_INFO_pszCRLDistribPoint2_set
    __swig_getmethods__["pszCRLDistribPoint2"] = _EUSignCP.EU_CR_INFO_pszCRLDistribPoint2_get
    if _newclass:
        pszCRLDistribPoint2 = _swig_property(_EUSignCP.EU_CR_INFO_pszCRLDistribPoint2_get, _EUSignCP.EU_CR_INFO_pszCRLDistribPoint2_set)
    __swig_setmethods__["bSubjType"] = _EUSignCP.EU_CR_INFO_bSubjType_set
    __swig_getmethods__["bSubjType"] = _EUSignCP.EU_CR_INFO_bSubjType_get
    if _newclass:
        bSubjType = _swig_property(_EUSignCP.EU_CR_INFO_bSubjType_get, _EUSignCP.EU_CR_INFO_bSubjType_set)
    __swig_setmethods__["dwSubjType"] = _EUSignCP.EU_CR_INFO_dwSubjType_set
    __swig_getmethods__["dwSubjType"] = _EUSignCP.EU_CR_INFO_dwSubjType_get
    if _newclass:
        dwSubjType = _swig_property(_EUSignCP.EU_CR_INFO_dwSubjType_get, _EUSignCP.EU_CR_INFO_dwSubjType_set)
    __swig_setmethods__["dwSubjSubType"] = _EUSignCP.EU_CR_INFO_dwSubjSubType_set
    __swig_getmethods__["dwSubjSubType"] = _EUSignCP.EU_CR_INFO_dwSubjSubType_get
    if _newclass:
        dwSubjSubType = _swig_property(_EUSignCP.EU_CR_INFO_dwSubjSubType_get, _EUSignCP.EU_CR_INFO_dwSubjSubType_set)
    __swig_setmethods__["bSelfSigned"] = _EUSignCP.EU_CR_INFO_bSelfSigned_set
    __swig_getmethods__["bSelfSigned"] = _EUSignCP.EU_CR_INFO_bSelfSigned_get
    if _newclass:
        bSelfSigned = _swig_property(_EUSignCP.EU_CR_INFO_bSelfSigned_get, _EUSignCP.EU_CR_INFO_bSelfSigned_set)
    __swig_setmethods__["pszSignIssuer"] = _EUSignCP.EU_CR_INFO_pszSignIssuer_set
    __swig_getmethods__["pszSignIssuer"] = _EUSignCP.EU_CR_INFO_pszSignIssuer_get
    if _newclass:
        pszSignIssuer = _swig_property(_EUSignCP.EU_CR_INFO_pszSignIssuer_get, _EUSignCP.EU_CR_INFO_pszSignIssuer_set)
    __swig_setmethods__["pszSignSerial"] = _EUSignCP.EU_CR_INFO_pszSignSerial_set
    __swig_getmethods__["pszSignSerial"] = _EUSignCP.EU_CR_INFO_pszSignSerial_get
    if _newclass:
        pszSignSerial = _swig_property(_EUSignCP.EU_CR_INFO_pszSignSerial_get, _EUSignCP.EU_CR_INFO_pszSignSerial_set)
    __swig_setmethods__["pszSubjUNZR"] = _EUSignCP.EU_CR_INFO_pszSubjUNZR_set
    __swig_getmethods__["pszSubjUNZR"] = _EUSignCP.EU_CR_INFO_pszSubjUNZR_get
    if _newclass:
        pszSubjUNZR = _swig_property(_EUSignCP.EU_CR_INFO_pszSubjUNZR_get, _EUSignCP.EU_CR_INFO_pszSubjUNZR_set)
    __swig_setmethods__["pszSubjCountry"] = _EUSignCP.EU_CR_INFO_pszSubjCountry_set
    __swig_getmethods__["pszSubjCountry"] = _EUSignCP.EU_CR_INFO_pszSubjCountry_get
    if _newclass:
        pszSubjCountry = _swig_property(_EUSignCP.EU_CR_INFO_pszSubjCountry_get, _EUSignCP.EU_CR_INFO_pszSubjCountry_set)

    def __init__(self):
        this = _EUSignCP.new_EU_CR_INFO()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _EUSignCP.delete_EU_CR_INFO
    __del__ = lambda self: None
EU_CR_INFO_swigregister = _EUSignCP.EU_CR_INFO_swigregister
EU_CR_INFO_swigregister(EU_CR_INFO)

class EU_USER_INFO(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, EU_USER_INFO, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, EU_USER_INFO, name)
    __repr__ = _swig_repr
    __swig_setmethods__["dwVersion"] = _EUSignCP.EU_USER_INFO_dwVersion_set
    __swig_getmethods__["dwVersion"] = _EUSignCP.EU_USER_INFO_dwVersion_get
    if _newclass:
        dwVersion = _swig_property(_EUSignCP.EU_USER_INFO_dwVersion_get, _EUSignCP.EU_USER_INFO_dwVersion_set)
    __swig_setmethods__["szCommonName"] = _EUSignCP.EU_USER_INFO_szCommonName_set
    __swig_getmethods__["szCommonName"] = _EUSignCP.EU_USER_INFO_szCommonName_get
    if _newclass:
        szCommonName = _swig_property(_EUSignCP.EU_USER_INFO_szCommonName_get, _EUSignCP.EU_USER_INFO_szCommonName_set)
    __swig_setmethods__["szLocality"] = _EUSignCP.EU_USER_INFO_szLocality_set
    __swig_getmethods__["szLocality"] = _EUSignCP.EU_USER_INFO_szLocality_get
    if _newclass:
        szLocality = _swig_property(_EUSignCP.EU_USER_INFO_szLocality_get, _EUSignCP.EU_USER_INFO_szLocality_set)
    __swig_setmethods__["szState"] = _EUSignCP.EU_USER_INFO_szState_set
    __swig_getmethods__["szState"] = _EUSignCP.EU_USER_INFO_szState_get
    if _newclass:
        szState = _swig_property(_EUSignCP.EU_USER_INFO_szState_get, _EUSignCP.EU_USER_INFO_szState_set)
    __swig_setmethods__["szOrganiztion"] = _EUSignCP.EU_USER_INFO_szOrganiztion_set
    __swig_getmethods__["szOrganiztion"] = _EUSignCP.EU_USER_INFO_szOrganiztion_get
    if _newclass:
        szOrganiztion = _swig_property(_EUSignCP.EU_USER_INFO_szOrganiztion_get, _EUSignCP.EU_USER_INFO_szOrganiztion_set)
    __swig_setmethods__["szOrgUnit"] = _EUSignCP.EU_USER_INFO_szOrgUnit_set
    __swig_getmethods__["szOrgUnit"] = _EUSignCP.EU_USER_INFO_szOrgUnit_get
    if _newclass:
        szOrgUnit = _swig_property(_EUSignCP.EU_USER_INFO_szOrgUnit_get, _EUSignCP.EU_USER_INFO_szOrgUnit_set)
    __swig_setmethods__["szTitle"] = _EUSignCP.EU_USER_INFO_szTitle_set
    __swig_getmethods__["szTitle"] = _EUSignCP.EU_USER_INFO_szTitle_get
    if _newclass:
        szTitle = _swig_property(_EUSignCP.EU_USER_INFO_szTitle_get, _EUSignCP.EU_USER_INFO_szTitle_set)
    __swig_setmethods__["szStreet"] = _EUSignCP.EU_USER_INFO_szStreet_set
    __swig_getmethods__["szStreet"] = _EUSignCP.EU_USER_INFO_szStreet_get
    if _newclass:
        szStreet = _swig_property(_EUSignCP.EU_USER_INFO_szStreet_get, _EUSignCP.EU_USER_INFO_szStreet_set)
    __swig_setmethods__["szPhone"] = _EUSignCP.EU_USER_INFO_szPhone_set
    __swig_getmethods__["szPhone"] = _EUSignCP.EU_USER_INFO_szPhone_get
    if _newclass:
        szPhone = _swig_property(_EUSignCP.EU_USER_INFO_szPhone_get, _EUSignCP.EU_USER_INFO_szPhone_set)
    __swig_setmethods__["szSurname"] = _EUSignCP.EU_USER_INFO_szSurname_set
    __swig_getmethods__["szSurname"] = _EUSignCP.EU_USER_INFO_szSurname_get
    if _newclass:
        szSurname = _swig_property(_EUSignCP.EU_USER_INFO_szSurname_get, _EUSignCP.EU_USER_INFO_szSurname_set)
    __swig_setmethods__["szGivenname"] = _EUSignCP.EU_USER_INFO_szGivenname_set
    __swig_getmethods__["szGivenname"] = _EUSignCP.EU_USER_INFO_szGivenname_get
    if _newclass:
        szGivenname = _swig_property(_EUSignCP.EU_USER_INFO_szGivenname_get, _EUSignCP.EU_USER_INFO_szGivenname_set)
    __swig_setmethods__["szEMail"] = _EUSignCP.EU_USER_INFO_szEMail_set
    __swig_getmethods__["szEMail"] = _EUSignCP.EU_USER_INFO_szEMail_get
    if _newclass:
        szEMail = _swig_property(_EUSignCP.EU_USER_INFO_szEMail_get, _EUSignCP.EU_USER_INFO_szEMail_set)
    __swig_setmethods__["szDNS"] = _EUSignCP.EU_USER_INFO_szDNS_set
    __swig_getmethods__["szDNS"] = _EUSignCP.EU_USER_INFO_szDNS_get
    if _newclass:
        szDNS = _swig_property(_EUSignCP.EU_USER_INFO_szDNS_get, _EUSignCP.EU_USER_INFO_szDNS_set)
    __swig_setmethods__["szEDRPOUCode"] = _EUSignCP.EU_USER_INFO_szEDRPOUCode_set
    __swig_getmethods__["szEDRPOUCode"] = _EUSignCP.EU_USER_INFO_szEDRPOUCode_get
    if _newclass:
        szEDRPOUCode = _swig_property(_EUSignCP.EU_USER_INFO_szEDRPOUCode_get, _EUSignCP.EU_USER_INFO_szEDRPOUCode_set)
    __swig_setmethods__["szDRFOCode"] = _EUSignCP.EU_USER_INFO_szDRFOCode_set
    __swig_getmethods__["szDRFOCode"] = _EUSignCP.EU_USER_INFO_szDRFOCode_get
    if _newclass:
        szDRFOCode = _swig_property(_EUSignCP.EU_USER_INFO_szDRFOCode_get, _EUSignCP.EU_USER_INFO_szDRFOCode_set)
    __swig_setmethods__["szNBUCode"] = _EUSignCP.EU_USER_INFO_szNBUCode_set
    __swig_getmethods__["szNBUCode"] = _EUSignCP.EU_USER_INFO_szNBUCode_get
    if _newclass:
        szNBUCode = _swig_property(_EUSignCP.EU_USER_INFO_szNBUCode_get, _EUSignCP.EU_USER_INFO_szNBUCode_set)
    __swig_setmethods__["szSPFMCode"] = _EUSignCP.EU_USER_INFO_szSPFMCode_set
    __swig_getmethods__["szSPFMCode"] = _EUSignCP.EU_USER_INFO_szSPFMCode_get
    if _newclass:
        szSPFMCode = _swig_property(_EUSignCP.EU_USER_INFO_szSPFMCode_get, _EUSignCP.EU_USER_INFO_szSPFMCode_set)
    __swig_setmethods__["szOCode"] = _EUSignCP.EU_USER_INFO_szOCode_set
    __swig_getmethods__["szOCode"] = _EUSignCP.EU_USER_INFO_szOCode_get
    if _newclass:
        szOCode = _swig_property(_EUSignCP.EU_USER_INFO_szOCode_get, _EUSignCP.EU_USER_INFO_szOCode_set)
    __swig_setmethods__["szOUCode"] = _EUSignCP.EU_USER_INFO_szOUCode_set
    __swig_getmethods__["szOUCode"] = _EUSignCP.EU_USER_INFO_szOUCode_get
    if _newclass:
        szOUCode = _swig_property(_EUSignCP.EU_USER_INFO_szOUCode_get, _EUSignCP.EU_USER_INFO_szOUCode_set)
    __swig_setmethods__["szUserCode"] = _EUSignCP.EU_USER_INFO_szUserCode_set
    __swig_getmethods__["szUserCode"] = _EUSignCP.EU_USER_INFO_szUserCode_get
    if _newclass:
        szUserCode = _swig_property(_EUSignCP.EU_USER_INFO_szUserCode_get, _EUSignCP.EU_USER_INFO_szUserCode_set)
    __swig_setmethods__["szUPN"] = _EUSignCP.EU_USER_INFO_szUPN_set
    __swig_getmethods__["szUPN"] = _EUSignCP.EU_USER_INFO_szUPN_get
    if _newclass:
        szUPN = _swig_property(_EUSignCP.EU_USER_INFO_szUPN_get, _EUSignCP.EU_USER_INFO_szUPN_set)
    __swig_setmethods__["szUNZR"] = _EUSignCP.EU_USER_INFO_szUNZR_set
    __swig_getmethods__["szUNZR"] = _EUSignCP.EU_USER_INFO_szUNZR_get
    if _newclass:
        szUNZR = _swig_property(_EUSignCP.EU_USER_INFO_szUNZR_get, _EUSignCP.EU_USER_INFO_szUNZR_set)
    __swig_setmethods__["szCountry"] = _EUSignCP.EU_USER_INFO_szCountry_set
    __swig_getmethods__["szCountry"] = _EUSignCP.EU_USER_INFO_szCountry_get
    if _newclass:
        szCountry = _swig_property(_EUSignCP.EU_USER_INFO_szCountry_get, _EUSignCP.EU_USER_INFO_szCountry_set)

    def __init__(self):
        this = _EUSignCP.new_EU_USER_INFO()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _EUSignCP.delete_EU_USER_INFO
    __del__ = lambda self: None
EU_USER_INFO_swigregister = _EUSignCP.EU_USER_INFO_swigregister
EU_USER_INFO_swigregister(EU_USER_INFO)

class EU_SCC_STATISTIC(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, EU_SCC_STATISTIC, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, EU_SCC_STATISTIC, name)
    __repr__ = _swig_repr
    __swig_setmethods__["dwVersion"] = _EUSignCP.EU_SCC_STATISTIC_dwVersion_set
    __swig_getmethods__["dwVersion"] = _EUSignCP.EU_SCC_STATISTIC_dwVersion_get
    if _newclass:
        dwVersion = _swig_property(_EUSignCP.EU_SCC_STATISTIC_dwVersion_get, _EUSignCP.EU_SCC_STATISTIC_dwVersion_set)
    __swig_setmethods__["dwlActiveSessions"] = _EUSignCP.EU_SCC_STATISTIC_dwlActiveSessions_set
    __swig_getmethods__["dwlActiveSessions"] = _EUSignCP.EU_SCC_STATISTIC_dwlActiveSessions_get
    if _newclass:
        dwlActiveSessions = _swig_property(_EUSignCP.EU_SCC_STATISTIC_dwlActiveSessions_get, _EUSignCP.EU_SCC_STATISTIC_dwlActiveSessions_set)
    __swig_setmethods__["dwlGatedSessions"] = _EUSignCP.EU_SCC_STATISTIC_dwlGatedSessions_set
    __swig_getmethods__["dwlGatedSessions"] = _EUSignCP.EU_SCC_STATISTIC_dwlGatedSessions_get
    if _newclass:
        dwlGatedSessions = _swig_property(_EUSignCP.EU_SCC_STATISTIC_dwlGatedSessions_get, _EUSignCP.EU_SCC_STATISTIC_dwlGatedSessions_set)
    __swig_setmethods__["dwlUnprotectedData"] = _EUSignCP.EU_SCC_STATISTIC_dwlUnprotectedData_set
    __swig_getmethods__["dwlUnprotectedData"] = _EUSignCP.EU_SCC_STATISTIC_dwlUnprotectedData_get
    if _newclass:
        dwlUnprotectedData = _swig_property(_EUSignCP.EU_SCC_STATISTIC_dwlUnprotectedData_get, _EUSignCP.EU_SCC_STATISTIC_dwlUnprotectedData_set)
    __swig_setmethods__["dwlProtectedData"] = _EUSignCP.EU_SCC_STATISTIC_dwlProtectedData_set
    __swig_getmethods__["dwlProtectedData"] = _EUSignCP.EU_SCC_STATISTIC_dwlProtectedData_get
    if _newclass:
        dwlProtectedData = _swig_property(_EUSignCP.EU_SCC_STATISTIC_dwlProtectedData_get, _EUSignCP.EU_SCC_STATISTIC_dwlProtectedData_set)

    def __init__(self):
        this = _EUSignCP.new_EU_SCC_STATISTIC()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _EUSignCP.delete_EU_SCC_STATISTIC
    __del__ = lambda self: None
EU_SCC_STATISTIC_swigregister = _EUSignCP.EU_SCC_STATISTIC_swigregister
EU_SCC_STATISTIC_swigregister(EU_SCC_STATISTIC)

class EU_TIME_INFO(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, EU_TIME_INFO, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, EU_TIME_INFO, name)
    __repr__ = _swig_repr
    __swig_setmethods__["dwVersion"] = _EUSignCP.EU_TIME_INFO_dwVersion_set
    __swig_getmethods__["dwVersion"] = _EUSignCP.EU_TIME_INFO_dwVersion_get
    if _newclass:
        dwVersion = _swig_property(_EUSignCP.EU_TIME_INFO_dwVersion_get, _EUSignCP.EU_TIME_INFO_dwVersion_set)
    __swig_setmethods__["bTimeAvail"] = _EUSignCP.EU_TIME_INFO_bTimeAvail_set
    __swig_getmethods__["bTimeAvail"] = _EUSignCP.EU_TIME_INFO_bTimeAvail_get
    if _newclass:
        bTimeAvail = _swig_property(_EUSignCP.EU_TIME_INFO_bTimeAvail_get, _EUSignCP.EU_TIME_INFO_bTimeAvail_set)
    __swig_setmethods__["bTimeStamp"] = _EUSignCP.EU_TIME_INFO_bTimeStamp_set
    __swig_getmethods__["bTimeStamp"] = _EUSignCP.EU_TIME_INFO_bTimeStamp_get
    if _newclass:
        bTimeStamp = _swig_property(_EUSignCP.EU_TIME_INFO_bTimeStamp_get, _EUSignCP.EU_TIME_INFO_bTimeStamp_set)
    __swig_setmethods__["Time"] = _EUSignCP.EU_TIME_INFO_Time_set
    __swig_getmethods__["Time"] = _EUSignCP.EU_TIME_INFO_Time_get
    if _newclass:
        Time = _swig_property(_EUSignCP.EU_TIME_INFO_Time_get, _EUSignCP.EU_TIME_INFO_Time_set)
    __swig_setmethods__["bSignTimeStampAvail"] = _EUSignCP.EU_TIME_INFO_bSignTimeStampAvail_set
    __swig_getmethods__["bSignTimeStampAvail"] = _EUSignCP.EU_TIME_INFO_bSignTimeStampAvail_get
    if _newclass:
        bSignTimeStampAvail = _swig_property(_EUSignCP.EU_TIME_INFO_bSignTimeStampAvail_get, _EUSignCP.EU_TIME_INFO_bSignTimeStampAvail_set)
    __swig_setmethods__["SignTimeStamp"] = _EUSignCP.EU_TIME_INFO_SignTimeStamp_set
    __swig_getmethods__["SignTimeStamp"] = _EUSignCP.EU_TIME_INFO_SignTimeStamp_get
    if _newclass:
        SignTimeStamp = _swig_property(_EUSignCP.EU_TIME_INFO_SignTimeStamp_get, _EUSignCP.EU_TIME_INFO_SignTimeStamp_set)

    def __init__(self):
        this = _EUSignCP.new_EU_TIME_INFO()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _EUSignCP.delete_EU_TIME_INFO
    __del__ = lambda self: None
EU_TIME_INFO_swigregister = _EUSignCP.EU_TIME_INFO_swigregister
EU_TIME_INFO_swigregister(EU_TIME_INFO)

class EU_KEY_MEDIA_DEVICE_INFO(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, EU_KEY_MEDIA_DEVICE_INFO, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, EU_KEY_MEDIA_DEVICE_INFO, name)
    __repr__ = _swig_repr
    __swig_setmethods__["dwVersion"] = _EUSignCP.EU_KEY_MEDIA_DEVICE_INFO_dwVersion_set
    __swig_getmethods__["dwVersion"] = _EUSignCP.EU_KEY_MEDIA_DEVICE_INFO_dwVersion_get
    if _newclass:
        dwVersion = _swig_property(_EUSignCP.EU_KEY_MEDIA_DEVICE_INFO_dwVersion_get, _EUSignCP.EU_KEY_MEDIA_DEVICE_INFO_dwVersion_set)
    __swig_setmethods__["pszDeviceNameAlias"] = _EUSignCP.EU_KEY_MEDIA_DEVICE_INFO_pszDeviceNameAlias_set
    __swig_getmethods__["pszDeviceNameAlias"] = _EUSignCP.EU_KEY_MEDIA_DEVICE_INFO_pszDeviceNameAlias_get
    if _newclass:
        pszDeviceNameAlias = _swig_property(_EUSignCP.EU_KEY_MEDIA_DEVICE_INFO_pszDeviceNameAlias_get, _EUSignCP.EU_KEY_MEDIA_DEVICE_INFO_pszDeviceNameAlias_set)

    def __init__(self):
        this = _EUSignCP.new_EU_KEY_MEDIA_DEVICE_INFO()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _EUSignCP.delete_EU_KEY_MEDIA_DEVICE_INFO
    __del__ = lambda self: None
EU_KEY_MEDIA_DEVICE_INFO_swigregister = _EUSignCP.EU_KEY_MEDIA_DEVICE_INFO_swigregister
EU_KEY_MEDIA_DEVICE_INFO_swigregister(EU_KEY_MEDIA_DEVICE_INFO)

class EU_INTERFACE(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, EU_INTERFACE, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, EU_INTERFACE, name)
    __repr__ = _swig_repr

    def Initialize(self):
        return _EUSignCP.EU_INTERFACE_Initialize(self)

    def IsInitialized(self):
        return _EUSignCP.EU_INTERFACE_IsInitialized(self)

    def Finalize(self):
        return _EUSignCP.EU_INTERFACE_Finalize(self)

    def ReadPrivateKey(self, pKeyMedia, pInfo):
        return _EUSignCP.EU_INTERFACE_ReadPrivateKey(self, pKeyMedia, pInfo)

    def IsPrivateKeyReaded(self):
        return _EUSignCP.EU_INTERFACE_IsPrivateKeyReaded(self)

    def ResetPrivateKey(self):
        return _EUSignCP.EU_INTERFACE_ResetPrivateKey(self)

    def SignData(self, pbData, dwDataLength, ppszSign, ppbSign):
        return _EUSignCP.EU_INTERFACE_SignData(self, pbData, dwDataLength, ppszSign, ppbSign)

    def VerifyData(self, pbData, dwDataLength, pszSign, pbSign, dwSignLength, pSignInfo):
        return _EUSignCP.EU_INTERFACE_VerifyData(self, pbData, dwDataLength, pszSign, pbSign, dwSignLength, pSignInfo)

    def SignDataInternal(self, bAppendCert, pbData, dwDataLength, ppszSignedData, ppbSignedData):
        return _EUSignCP.EU_INTERFACE_SignDataInternal(self, bAppendCert, pbData, dwDataLength, ppszSignedData, ppbSignedData)

    def VerifyDataInternal(self, pszSignedData, pbSignedData, dwSignedDataLength, ppbData, pSignInfo):
        return _EUSignCP.EU_INTERFACE_VerifyDataInternal(self, pszSignedData, pbSignedData, dwSignedDataLength, ppbData, pSignInfo)

    def SetUIMode(self, bUIMode):
        return _EUSignCP.EU_INTERFACE_SetUIMode(self, bUIMode)

    def HashData(self, pbData, dwDataLength, ppszHash, ppbHash):
        return _EUSignCP.EU_INTERFACE_HashData(self, pbData, dwDataLength, ppszHash, ppbHash)

    def HashDataContinue(self, pbData, dwDataLength):
        return _EUSignCP.EU_INTERFACE_HashDataContinue(self, pbData, dwDataLength)

    def HashDataEnd(self, ppszHash, ppbHash):
        return _EUSignCP.EU_INTERFACE_HashDataEnd(self, ppszHash, ppbHash)

    def HashFile(self, pszFileName, ppszHash, ppbHash):
        return _EUSignCP.EU_INTERFACE_HashFile(self, pszFileName, ppszHash, ppbHash)

    def SignHash(self, pszHash, pbHash, dwHashLength, ppszSign, ppbSign):
        return _EUSignCP.EU_INTERFACE_SignHash(self, pszHash, pbHash, dwHashLength, ppszSign, ppbSign)

    def VerifyHash(self, pszHash, pbHash, dwHashLength, pszSign, pbSign, dwSignLength, pSignInfo):
        return _EUSignCP.EU_INTERFACE_VerifyHash(self, pszHash, pbHash, dwHashLength, pszSign, pbSign, dwSignLength, pSignInfo)

    def EnumKeyMediaTypes(self, dwTypeIndex, pszTypeDescription):
        return _EUSignCP.EU_INTERFACE_EnumKeyMediaTypes(self, dwTypeIndex, pszTypeDescription)

    def EnumKeyMediaDevices(self, dwTypeIndex, dwDeviceIndex, pszDeviceDescription):
        return _EUSignCP.EU_INTERFACE_EnumKeyMediaDevices(self, dwTypeIndex, dwDeviceIndex, pszDeviceDescription)

    def GetFileStoreSettings(self, pszPath):
        return _EUSignCP.EU_INTERFACE_GetFileStoreSettings(self, pszPath)

    def SetFileStoreSettings(self, pszPath):
        return _EUSignCP.EU_INTERFACE_SetFileStoreSettings(self, pszPath)

    def GetProxySettings(self, pbUseProxy):
        return _EUSignCP.EU_INTERFACE_GetProxySettings(self, pbUseProxy)

    def SetProxySettings(self, bUseProxy):
        return _EUSignCP.EU_INTERFACE_SetProxySettings(self, bUseProxy)

    def GetOCSPSettings(self, pbUseOCSP):
        return _EUSignCP.EU_INTERFACE_GetOCSPSettings(self, pbUseOCSP)

    def SetOCSPSettings(self, bUseOCSP):
        return _EUSignCP.EU_INTERFACE_SetOCSPSettings(self, bUseOCSP)

    def GetTSPSettings(self, pbGetStamps):
        return _EUSignCP.EU_INTERFACE_GetTSPSettings(self, pbGetStamps)

    def SetTSPSettings(self, bGetStamps):
        return _EUSignCP.EU_INTERFACE_SetTSPSettings(self, bGetStamps)

    def GetLDAPSettings(self, pbUseLDAP):
        return _EUSignCP.EU_INTERFACE_GetLDAPSettings(self, pbUseLDAP)

    def SetLDAPSettings(self, bUseLDAP):
        return _EUSignCP.EU_INTERFACE_SetLDAPSettings(self, bUseLDAP)

    def GetCMPSettings(self, pbUseCMP):
        return _EUSignCP.EU_INTERFACE_GetCMPSettings(self, pbUseCMP)

    def SetCMPSettings(self, bUseCMP):
        return _EUSignCP.EU_INTERFACE_SetCMPSettings(self, bUseCMP)

    def DoesNeedSetSettings(self):
        return _EUSignCP.EU_INTERFACE_DoesNeedSetSettings(self)

    def RawSignData(self, pbData, dwDataLength, ppszSign, ppbSign):
        return _EUSignCP.EU_INTERFACE_RawSignData(self, pbData, dwDataLength, ppszSign, ppbSign)

    def RawVerifyData(self, pbData, dwDataLength, pszSign, pbSign, dwSignLength, pSignInfo):
        return _EUSignCP.EU_INTERFACE_RawVerifyData(self, pbData, dwDataLength, pszSign, pbSign, dwSignLength, pSignInfo)

    def RawSignHash(self, pszHash, pbHash, dwHashLength, ppszSign, ppbSign):
        return _EUSignCP.EU_INTERFACE_RawSignHash(self, pszHash, pbHash, dwHashLength, ppszSign, ppbSign)

    def RawVerifyHash(self, pszHash, pbHash, dwHashLength, pszSign, pbSign, dwSignLength, pInfo):
        return _EUSignCP.EU_INTERFACE_RawVerifyHash(self, pszHash, pbHash, dwHashLength, pszSign, pbSign, dwSignLength, pInfo)

    def RawSignFile(self, pszFileName, pszFileNameWithSign):
        return _EUSignCP.EU_INTERFACE_RawSignFile(self, pszFileName, pszFileNameWithSign)

    def RawVerifyFile(self, pszFileNameWithSign, pszFileName, pSignInfo):
        return _EUSignCP.EU_INTERFACE_RawVerifyFile(self, pszFileNameWithSign, pszFileName, pSignInfo)

    def DevelopData(self, pszEnvelopedData, pbEnvelopedData, dwEnvelopedDataLength, ppbData, pInfo):
        return _EUSignCP.EU_INTERFACE_DevelopData(self, pszEnvelopedData, pbEnvelopedData, dwEnvelopedDataLength, ppbData, pInfo)

    def ReadPrivateKeyBinary(self, pbPrivateKey, dwPrivateKeyLength, pszPassword, pInfo):
        return _EUSignCP.EU_INTERFACE_ReadPrivateKeyBinary(self, pbPrivateKey, dwPrivateKeyLength, pszPassword, pInfo)

    def ReadPrivateKeyFile(self, pszPrivateKeyFileName, pszPassword, pInfo):
        return _EUSignCP.EU_INTERFACE_ReadPrivateKeyFile(self, pszPrivateKeyFileName, pszPassword, pInfo)

    def SessionDestroy(self, pvSession):
        return _EUSignCP.EU_INTERFACE_SessionDestroy(self, pvSession)

    def ClientSessionCreateStep1(self, dwExpireTime, ppvClientSession, ppbClientData):
        return _EUSignCP.EU_INTERFACE_ClientSessionCreateStep1(self, dwExpireTime, ppvClientSession, ppbClientData)

    def ServerSessionCreateStep1(self, dwExpireTime, pbClientData, dwClientDataLength, ppvServerSession, ppbServerData):
        return _EUSignCP.EU_INTERFACE_ServerSessionCreateStep1(self, dwExpireTime, pbClientData, dwClientDataLength, ppvServerSession, ppbServerData)

    def ClientSessionCreateStep2(self, pvClientSession, pbServerData, dwServerDataLength, ppbClientData):
        return _EUSignCP.EU_INTERFACE_ClientSessionCreateStep2(self, pvClientSession, pbServerData, dwServerDataLength, ppbClientData)

    def ServerSessionCreateStep2(self, pvServerSession, pbClientData, dwClientDataLength):
        return _EUSignCP.EU_INTERFACE_ServerSessionCreateStep2(self, pvServerSession, pbClientData, dwClientDataLength)

    def SessionIsInitialized(self, pvSession):
        return _EUSignCP.EU_INTERFACE_SessionIsInitialized(self, pvSession)

    def SessionSave(self, pvSession, ppbSessionData):
        return _EUSignCP.EU_INTERFACE_SessionSave(self, pvSession, ppbSessionData)

    def SessionLoad(self, pbSessionData, dwSessionDataLength, ppvSession):
        return _EUSignCP.EU_INTERFACE_SessionLoad(self, pbSessionData, dwSessionDataLength, ppvSession)

    def SessionCheckCertificates(self, pvSession):
        return _EUSignCP.EU_INTERFACE_SessionCheckCertificates(self, pvSession)

    def SessionEncrypt(self, pvSession, pbData, dwDataLength, ppbEncryptedData):
        return _EUSignCP.EU_INTERFACE_SessionEncrypt(self, pvSession, pbData, dwDataLength, ppbEncryptedData)

    def SessionDecrypt(self, pvSession, pbEncryptedData, dwEncryptedDataLength, ppbData):
        return _EUSignCP.EU_INTERFACE_SessionDecrypt(self, pvSession, pbEncryptedData, dwEncryptedDataLength, ppbData)

    def SessionGetPeerCertificateInfo(self, pvSession, pInfo):
        return _EUSignCP.EU_INTERFACE_SessionGetPeerCertificateInfo(self, pvSession, pInfo)

    def GetModeSettings(self, pbOfflineMode):
        return _EUSignCP.EU_INTERFACE_GetModeSettings(self, pbOfflineMode)

    def SetModeSettings(self, bOfflineMode):
        return _EUSignCP.EU_INTERFACE_SetModeSettings(self, bOfflineMode)

    def DevelopFile(self, pszEnvelopedFileName, pszFileName, pInfo):
        return _EUSignCP.EU_INTERFACE_DevelopFile(self, pszEnvelopedFileName, pszFileName, pInfo)

    def GetCertificateInfoEx(self, pszIssuer, pszSerial, ppInfo):
        return _EUSignCP.EU_INTERFACE_GetCertificateInfoEx(self, pszIssuer, pszSerial, ppInfo)

    def GetCRInfo(self, pbRequest, dwRequest, ppInfo):
        return _EUSignCP.EU_INTERFACE_GetCRInfo(self, pbRequest, dwRequest, ppInfo)

    def GetSignsCount(self, pszSign, pbSign, dwSignLength, pdwCount):
        return _EUSignCP.EU_INTERFACE_GetSignsCount(self, pszSign, pbSign, dwSignLength, pdwCount)

    def GetSignerInfo(self, dwSignIndex, pszSign, pbSign, dwSignLength, ppInfo, ppbCertificate):
        return _EUSignCP.EU_INTERFACE_GetSignerInfo(self, dwSignIndex, pszSign, pbSign, dwSignLength, ppInfo, ppbCertificate)

    def HashDataWithParams(self, pbCertificate, dwCertificateLength, pbData, dwDataLength, ppszHash, ppbHash):
        return _EUSignCP.EU_INTERFACE_HashDataWithParams(self, pbCertificate, dwCertificateLength, pbData, dwDataLength, ppszHash, ppbHash)

    def HashDataBeginWithParams(self, pbCertificate, dwCertificateLength):
        return _EUSignCP.EU_INTERFACE_HashDataBeginWithParams(self, pbCertificate, dwCertificateLength)

    def HashFileWithParams(self, pbCertificate, dwCertificateLength, pszFileName, ppszHash, ppbHash):
        return _EUSignCP.EU_INTERFACE_HashFileWithParams(self, pbCertificate, dwCertificateLength, pszFileName, ppszHash, ppbHash)

    def EnvelopDataToRecipients(self, dwRecipientCerts, bSignData, pbData, dwDataLength, ppszEnvelopedData, ppbEnvelopedData):
        return _EUSignCP.EU_INTERFACE_EnvelopDataToRecipients(self, dwRecipientCerts, bSignData, pbData, dwDataLength, ppszEnvelopedData, ppbEnvelopedData)

    def EnvelopFileToRecipients(self, dwRecipientCerts, bSignData, pszFileName, pszEnvelopedFileName):
        return _EUSignCP.EU_INTERFACE_EnvelopFileToRecipients(self, dwRecipientCerts, bSignData, pszFileName, pszEnvelopedFileName)

    def EnvelopDataExWithDynamicKey(self, pszRecipientCertIssuers, pszRecipientCertSerials, bSignData, bAppendCert, pbData, dwDataLength, ppszEnvelopedData, ppbEnvelopedData):
        return _EUSignCP.EU_INTERFACE_EnvelopDataExWithDynamicKey(self, pszRecipientCertIssuers, pszRecipientCertSerials, bSignData, bAppendCert, pbData, dwDataLength, ppszEnvelopedData, ppbEnvelopedData)

    def EnvelopDataToRecipientsWithDynamicKey(self, dwRecipientCerts, bSignData, bAppendCert, pbData, dwDataLength, ppszEnvelopedData, ppbEnvelopedData):
        return _EUSignCP.EU_INTERFACE_EnvelopDataToRecipientsWithDynamicKey(self, dwRecipientCerts, bSignData, bAppendCert, pbData, dwDataLength, ppszEnvelopedData, ppbEnvelopedData)

    def EnvelopFileExWithDynamicKey(self, pszRecipientCertIssuers, pszRecipientCertSerials, bSignData, bAppendCert, pszFileName, pszEnvelopedFileName):
        return _EUSignCP.EU_INTERFACE_EnvelopFileExWithDynamicKey(self, pszRecipientCertIssuers, pszRecipientCertSerials, bSignData, bAppendCert, pszFileName, pszEnvelopedFileName)

    def EnvelopFileToRecipientsWithDynamicKey(self, dwRecipientCerts, bSignData, bAppendCert, pszFileName, pszEnvelopedFileName):
        return _EUSignCP.EU_INTERFACE_EnvelopFileToRecipientsWithDynamicKey(self, dwRecipientCerts, bSignData, bAppendCert, pszFileName, pszEnvelopedFileName)

    def SetRuntimeParameter(self, pszParameterName, pvParameterValue):
        return _EUSignCP.EU_INTERFACE_SetRuntimeParameter(self, pszParameterName, pvParameterValue)

    def DevelopDataEx(self, pszEnvelopedData, pbEnvelopedData, dwEnvelopedDataLength, pbSenderCert, dwSenderCertSize, ppbData, pInfo):
        return _EUSignCP.EU_INTERFACE_DevelopDataEx(self, pszEnvelopedData, pbEnvelopedData, dwEnvelopedDataLength, pbSenderCert, dwSenderCertSize, ppbData, pInfo)

    def GetOCSPAccessInfoModeSettings(self, pbEnabled):
        return _EUSignCP.EU_INTERFACE_GetOCSPAccessInfoModeSettings(self, pbEnabled)

    def SetOCSPAccessInfoModeSettings(self, bEnabled):
        return _EUSignCP.EU_INTERFACE_SetOCSPAccessInfoModeSettings(self, bEnabled)

    def EnumOCSPAccessInfoSettings(self, dwIndex, pszIssuerCN):
        return _EUSignCP.EU_INTERFACE_EnumOCSPAccessInfoSettings(self, dwIndex, pszIssuerCN)

    def GetOCSPAccessInfoSettings(self, pszIssuerCN):
        return _EUSignCP.EU_INTERFACE_GetOCSPAccessInfoSettings(self, pszIssuerCN)

    def SetOCSPAccessInfoSettings(self, pszIssuerCN):
        return _EUSignCP.EU_INTERFACE_SetOCSPAccessInfoSettings(self, pszIssuerCN)

    def DeleteOCSPAccessInfoSettings(self, pszIssuerCN):
        return _EUSignCP.EU_INTERFACE_DeleteOCSPAccessInfoSettings(self, pszIssuerCN)

    def ParseCertificateEx(self, pbCertificate, dwCertificateLength, ppInfo):
        return _EUSignCP.EU_INTERFACE_ParseCertificateEx(self, pbCertificate, dwCertificateLength, ppInfo)

    def ClientDynamicKeySessionCreate(self, dwExpireTime, pszServerCertIssuer, pszServerCertSerial, pbServerCert, dwServerCertLength, ppvClientSession, ppbClientData):
        return _EUSignCP.EU_INTERFACE_ClientDynamicKeySessionCreate(self, dwExpireTime, pszServerCertIssuer, pszServerCertSerial, pbServerCert, dwServerCertLength, ppvClientSession, ppbClientData)

    def ServerDynamicKeySessionCreate(self, dwExpireTime, pbClientData, dwClientDataLength, ppvServerSession):
        return _EUSignCP.EU_INTERFACE_ServerDynamicKeySessionCreate(self, dwExpireTime, pbClientData, dwClientDataLength, ppvServerSession)

    def GetDataFromSignedData(self, pszSignedData, pbSignedData, dwSignedDataLength, ppbData):
        return _EUSignCP.EU_INTERFACE_GetDataFromSignedData(self, pszSignedData, pbSignedData, dwSignedDataLength, ppbData)

    def VerifyHashOnTimeEx(self, pszHash, pbHash, dwHashLength, dwSignIndex, pszSign, pbSign, dwSignLength, pOnTime, bOffline, bNoCRL, pInfo):
        return _EUSignCP.EU_INTERFACE_VerifyHashOnTimeEx(self, pszHash, pbHash, dwHashLength, dwSignIndex, pszSign, pbSign, dwSignLength, pOnTime, bOffline, bNoCRL, pInfo)

    def VerifyDataOnTimeEx(self, pbData, dwDataLength, dwSignIndex, pszSign, pbSign, dwSignLength, pOnTime, bOffline, bNoCRL, pInfo):
        return _EUSignCP.EU_INTERFACE_VerifyDataOnTimeEx(self, pbData, dwDataLength, dwSignIndex, pszSign, pbSign, dwSignLength, pOnTime, bOffline, bNoCRL, pInfo)

    def VerifyDataInternalOnTimeEx(self, dwSignIndex, pszSignedData, pbSignedData, dwSignedDataLength, pOnTime, bOffline, bNoCRL, ppbData, pInfo):
        return _EUSignCP.EU_INTERFACE_VerifyDataInternalOnTimeEx(self, dwSignIndex, pszSignedData, pbSignedData, dwSignedDataLength, pOnTime, bOffline, bNoCRL, ppbData, pInfo)

    def EnvelopDataToRecipientsOffline(self, dwRecipientCerts, bSignData, pbData, dwDataLength, bCheckRecipientCertsOffline, bCheckRecipientCertsNoCRL, ppszEnvelopedData, ppbEnvelopedData):
        return _EUSignCP.EU_INTERFACE_EnvelopDataToRecipientsOffline(self, dwRecipientCerts, bSignData, pbData, dwDataLength, bCheckRecipientCertsOffline, bCheckRecipientCertsNoCRL, ppszEnvelopedData, ppbEnvelopedData)

    def GeneratePRNGSequence(self, pbData, dwDataLength):
        return _EUSignCP.EU_INTERFACE_GeneratePRNGSequence(self, pbData, dwDataLength)

    def __init__(self):
        this = _EUSignCP.new_EU_INTERFACE()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _EUSignCP.delete_EU_INTERFACE
    __del__ = lambda self: None
EU_INTERFACE_swigregister = _EUSignCP.EU_INTERFACE_swigregister
EU_INTERFACE_swigregister(EU_INTERFACE)


def EULoad():
    return _EUSignCP.EULoad()
EULoad = _EUSignCP.EULoad

def EUGetInterface() -> EU_INTERFACE:
    return _EUSignCP.EUGetInterface()
EUGetInterface = _EUSignCP.EUGetInterface

def EUUnload():
    return _EUSignCP.EUUnload()
EUUnload = _EUSignCP.EUUnload
# This file is compatible with both classic and new-style classes.


